@@ -40,7 +40,7 @@
 #endif
 
 #if defined(HAVE_MED)
-#include "med.h"
+#include <med.h>
 #endif
 
 #if defined(HAVE_POST)
@@ -80,7 +80,8 @@ std::vector<std::pair<std::string, std::string> > GetUsage()
   s.push_back(mp("-bin", "Create binary files when possible"));
   s.push_back(mp("-refine", "Perform uniform mesh refinement, then exit"));
   s.push_back(mp("-barycentric_refine", "Perform barycentric mesh refinement, then exit"));
-  s.push_back(mp("-reclassify", "Reclassify surface mesh, then exit"));
+  s.push_back(mp("-reclassify angle", "Reclassify surface mesh, then exit"));
+  s.push_back(mp("-reparam angle", "Reparametrize surface mesh, then exit"));
   s.push_back(mp("-part int", "Partition after batch mesh generation"));
   s.push_back(mp("-part_weight tri|quad|tet|hex|pri|pyr|trih int",
                  "Weight of a triangle/quad/etc. during partitioning"));
@@ -143,6 +144,7 @@ std::vector<std::pair<std::string, std::string> > GetUsage()
   s.push_back(mp("-new", "Create new model before merge next file"));
   s.push_back(mp("-merge", "Merge next files"));
   s.push_back(mp("-open", "Open next files"));
+  s.push_back(mp("-log filename", "Log all messages to filename"));
 #if defined(HAVE_FLTK)
   s.push_back(mp("-a, -g, -m, -s, -p", "Start in automatic, geometry, mesh, solver or "
                  "post-processing mode"));
@@ -290,7 +292,7 @@ void PrintUsage(const std::string &name)
 {
   Msg::Direct("Usage: %s [options] [files]", name.c_str());
   std::vector<std::pair<std::string, std::string> > s = GetUsage();
-  for(unsigned int i = 0; i < s.size(); i++){
+  for(std::size_t i = 0; i < s.size(); i++){
     std::string a = s[i].first, b = s[i].second;
     if(b.empty()){
       Msg::Direct("%s", a.c_str());
@@ -429,20 +431,44 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
         i++;
       }
       else if(!strcmp(argv[i] + 1, "log")) {
-        Msg::SetLogFile("gmsh.log");
         i++;
+        if(argv[i]){
+          Msg::SetLogFile(argv[i++]);
+        }
+        else{
+          Msg::Error("Missing filename");
+          if(exitOnError) Msg::Exit(1);
+        }
       }
       else if(!strcmp(argv[i] + 1, "refine")) {
         CTX::instance()->batch = 5;
         i++;
       }
-      else if(!strcmp(argv[i] + 1, "reclassify")) {
+      else if(!strcmp(argv[i] + 1, "barycentric_refine")) {
         CTX::instance()->batch = 6;
         i++;
       }
-      else if(!strcmp(argv[i] + 1, "barycentric_refine")) {
-        CTX::instance()->batch = 7;
+      else if(!strcmp(argv[i] + 1, "reclassify")) {
         i++;
+        if(argv[i]){
+          CTX::instance()->batch = 7 ;
+          CTX::instance()->batchSomeValue = atof(argv[i]);
+        }
+        else{
+          Msg::Error("Missing number");
+          if(exitOnError) Msg::Exit(1);
+        }
+      }
+      else if(!strcmp(argv[i] + 1, "reparam")) {
+        i++;
+        if(argv[i]){
+          CTX::instance()->batch = 8 ;
+          CTX::instance()->batchSomeValue = atof(argv[i]);
+        }
+        else{
+          Msg::Error("Missing number");
+          if(exitOnError) Msg::Exit(1);
+        }
       }
       else if(!strcmp(argv[i] + 1, "part")) {
         i++;
@@ -622,7 +648,12 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
       }
       else if(!strcmp(argv[i] + 1, "debugSurface")) {
 	i++;
-        CTX::instance()->debugSurface = atoi(argv[i++]);
+        if(argv[i])
+          CTX::instance()->debugSurface = atoi(argv[i++]);
+        else{
+          Msg::Error("Missing number");
+          if(exitOnError) Msg::Exit(1);
+        }
       }
       else if(!strcmp(argv[i] + 1, "ho_max")) {
         i++;
@@ -819,17 +850,17 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
         while(i < argc) {
           std::string fileName = std::string(argv[i]) + "_new";
 #if defined(HAVE_POST)
-          unsigned int n = PView::list.size();
+          std::size_t n = PView::list.size();
 #endif
           OpenProject(argv[i]);
 #if defined(HAVE_POST)
           // convert post-processing views to latest binary format
-          for(unsigned int j = n; j < PView::list.size(); j++)
+          for(std::size_t j = n; j < PView::list.size(); j++)
             PView::list[j]->write(fileName, 1, (j == n) ? false : true);
 #endif
           // convert mesh to latest binary format
           if(GModel::current()->getMeshStatus() > 0){
-            CTX::instance()->mesh.mshFileVersion = 4.0;
+            CTX::instance()->mesh.mshFileVersion = 4.1;
             CTX::instance()->mesh.binary = 1;
             CreateOutputFile(fileName, FORMAT_MSH);
           }
@@ -929,7 +960,7 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
         if(argv[i]) {
           CTX::instance()->mesh.toleranceEdgeLength = atof(argv[i++]);
           if(CTX::instance()->mesh.toleranceEdgeLength <= 0.0){
-            Msg::Error("Tolerance for model edge length must be > 0 (here %g)",
+            Msg::Error("Tolerance for model curve length must be > 0 (here %g)",
                        CTX::instance()->mesh.toleranceEdgeLength);
             if(exitOnError) Msg::Exit(1);
           }
@@ -1079,10 +1110,6 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
         CTX::instance()->mesh.algoRecombine = 2;
         i++;
       }
-      else if(!strcmp(argv[i] + 1, "meshdiscrete")) {
-        i++;
-        CTX::instance()->meshDiscrete = 1;
-      }
       else if(!strcmp(argv[i] + 1, "format") || !strcmp(argv[i] + 1, "f")) {
         i++;
         if(argv[i]) {
@@ -1153,7 +1180,7 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
       else if(!strcmp(argv[i] + 1, "help_options")) {
         std::vector<std::string> s;
         PrintOptions(0, GMSH_FULLRC, 0, 1, 0, &s);
-        for(unsigned int i = 0; i < s.size(); i++)
+        for(std::size_t i = 0; i < s.size(); i++)
           Msg::Direct("%s\n", s[i].c_str());
         Msg::Exit(0);
       }
