@@ -44,10 +44,12 @@
 #include "CommandLine.h"
 #include "Context.h"
 #include "StringUtils.h"
-#include "Generator.h"
 #include "gl2ps.h"
 #include "gmshPopplerWrapper.h"
 #include "PixelBuffer.h"
+#if defined(HAVE_TOUCHBAR)
+#include "touchBar.h"
+#endif
 
 #if defined(HAVE_3M)
 #include "3M.h"
@@ -388,7 +390,7 @@ static void fatal_error_handler(const char *fmt, ...)
   Msg::Fatal("%s (FLTK internal error)", str);
 }
 
-void FlGui::applyColorScheme()
+void FlGui::applyColorScheme(bool redraw)
 {
   static int first = true;
   int N = 4 + FL_NUM_GRAY;
@@ -415,9 +417,7 @@ void FlGui::applyColorScheme()
       int d = (int)(min + i * (max - min) / (FL_NUM_GRAY - 1.));
       Fl::set_color(fl_gray_ramp(i), d, d, d);
     }
-    if(available()) Fl::reload_scheme();
     Fl::set_color(FL_SELECTION_COLOR, 200, 200, 200);
-    if(available()) updateViews(true, true);
   }
   else if(!first && available() && CTX::instance()->guiColorScheme == 0) {
     // retore default colors (only if not calling the routine from the
@@ -428,12 +428,26 @@ void FlGui::applyColorScheme()
     for(int i = 0; i < FL_NUM_GRAY; i++) {
       Fl::set_color(fl_gray_ramp(i), r[4 + i], g[4 + i], b[4 + i]);
     }
-    Fl::reload_scheme();
     Fl::set_color(FL_SELECTION_COLOR, r[3], g[3], b[3]);
-    updateViews(true, true);
   }
 
   first = false;
+
+  // also change default box type here (to thin versions)
+  Fl::set_boxtype(FL_UP_BOX, FL_THIN_UP_BOX);
+  Fl::set_boxtype(FL_DOWN_BOX, FL_THIN_DOWN_BOX);
+  Fl::set_boxtype(FL_UP_FRAME, FL_THIN_UP_FRAME);
+  Fl::set_boxtype(FL_DOWN_FRAME, FL_THIN_DOWN_FRAME);
+
+  // thinner scrollbars
+  Fl::scrollbar_size(std::max(10, FL_NORMAL_SIZE));
+
+  if(redraw && available()){
+    updateViews(true, true);
+    for (Fl_Window *win = Fl::first_window(); win; win = Fl::next_window(win)) {
+      win->redraw();
+    }
+  }
 }
 
 FlGui::FlGui(int argc, char **argv)
@@ -446,6 +460,7 @@ FlGui::FlGui(int argc, char **argv)
   Fl_Mac_App_Menu::about = "About Gmsh";
   Fl_Mac_App_Menu::hide = "Hide Gmsh";
   Fl_Mac_App_Menu::quit = "Quit Gmsh";
+  Fl_Mac_App_Menu::print = ""; // this sometimes crashes
 #endif
 
   // tell fltk we're (potentially) in multi-threaded mode
@@ -455,14 +470,14 @@ FlGui::FlGui(int argc, char **argv)
   if(CTX::instance()->display.size())
     Fl::display(CTX::instance()->display.c_str());
 
-  // apply color scheme before widget creation (noop if default color scheme is
-  // selected), so that there's no color "flashing"
-  applyColorScheme();
-
   // add new box types (dx dy dw dh)
   Fl::set_boxtype(GMSH_SIMPLE_RIGHT_BOX, simple_right_box_draw, 0, 0, 1, 0);
   Fl::set_boxtype(GMSH_SIMPLE_TOP_BOX, simple_top_box_draw, 0, 1, 0, 1);
 
+  // apply color scheme before widget creation (noop if default color scheme is
+  // selected), so that there's no color "flashing"
+  applyColorScheme();
+
   // add gamepad handler
   if(CTX::instance()->gamepad) Fl::add_timeout(5., gamepad_handler, (void *)0);
 
@@ -548,8 +563,8 @@ FlGui::FlGui(int argc, char **argv)
   graph[0]->getWindow()->show(argc > 0 ? 1 : 0, argv);
   if(graph[0]->getMenuWindow()) graph[0]->getMenuWindow()->show();
 
-  // re-apply color scheme (necessary for some reason to get the selection color
-  // right)
+  // re-apply color scheme (necessary after open_display to get the selection
+  // color and boxtypes right)
   applyColorScheme();
 
   // graphic window should have the initial focus (so we can e.g. directly loop
@@ -570,7 +585,7 @@ FlGui::FlGui(int argc, char **argv)
   }
   setGraphicTitle(GModel::current()->getFileName());
 
-  // create fullscreen window
+  // create window that will be used for fullscreen display
   fullscreen = new openglWindow(100, 100, 100, 100);
   int mode = FL_RGB | FL_DEPTH | (CTX::instance()->db ? FL_DOUBLE : FL_SINGLE);
   if(CTX::instance()->antialiasing) mode |= FL_MULTISAMPLE;
@@ -580,7 +595,6 @@ FlGui::FlGui(int argc, char **argv)
   }
   fullscreen->mode(mode);
   fullscreen->end();
-  fullscreen->fullscreen();
 #if !defined(__APPLE__)
   fullscreen->icon(graph[0]->getWindow()->icon());
 #endif
@@ -605,12 +619,16 @@ FlGui::FlGui(int argc, char **argv)
   callForSolverPlugin(-1);
 
   // draw
-  for(unsigned int i = 0; i < graph.size(); i++)
-    for(unsigned int j = 0; j < graph[i]->gl.size(); j++)
+  for(std::size_t i = 0; i < graph.size(); i++)
+    for(std::size_t j = 0; j < graph[i]->gl.size(); j++)
       graph[i]->gl[j]->redraw();
 
   if(CTX::instance()->showOptionsOnStartup) options->win->show();
   if(CTX::instance()->showMessagesOnStartup) graph[0]->showMessages();
+
+#if defined(HAVE_TOUCHBAR)
+  showTouchBar();
+#endif
 }
 
 bool FlGui::available() { return _instance != 0; }
@@ -641,6 +659,10 @@ int FlGui::run()
   // draw the scene
   drawContext::global()->draw();
 
+#if defined(HAVE_TOUCHBAR)
+  updateTouchBar();
+#endif
+
   return Fl::run();
 }
 
@@ -703,32 +725,32 @@ int FlGui::testGlobalShortcuts(int event)
     status = 1;
   }
   else if(Fl::test_shortcut('e')) {
-    for(unsigned int i = 0; i < graph.size(); i++)
-      for(unsigned int j = 0; j < graph[i]->gl.size(); j++)
+    for(std::size_t i = 0; i < graph.size(); i++)
+      for(std::size_t j = 0; j < graph[i]->gl.size(); j++)
         graph[i]->gl[j]->endSelection = 1;
     status = 0; // trick: do as if we didn't use it
   }
   else if(Fl::test_shortcut('u')) {
-    for(unsigned int i = 0; i < graph.size(); i++)
-      for(unsigned int j = 0; j < graph[i]->gl.size(); j++)
+    for(std::size_t i = 0; i < graph.size(); i++)
+      for(std::size_t j = 0; j < graph[i]->gl.size(); j++)
         graph[i]->gl[j]->undoSelection = 1;
     status = 0; // trick: do as if we didn't use it
   }
   else if(Fl::test_shortcut('i')) {
-    for(unsigned int i = 0; i < graph.size(); i++)
-      for(unsigned int j = 0; j < graph[i]->gl.size(); j++)
+    for(std::size_t i = 0; i < graph.size(); i++)
+      for(std::size_t j = 0; j < graph[i]->gl.size(); j++)
         graph[i]->gl[j]->invertSelection = 1;
     status = 0; // trick: do as if we didn't use it
   }
   else if(Fl::test_shortcut('q')) {
-    for(unsigned int i = 0; i < graph.size(); i++)
-      for(unsigned int j = 0; j < graph[i]->gl.size(); j++)
+    for(std::size_t i = 0; i < graph.size(); i++)
+      for(std::size_t j = 0; j < graph[i]->gl.size(); j++)
         graph[i]->gl[j]->quitSelection = 1;
     status = 0; // trick: do as if we didn't use it
   }
   else if(Fl::test_shortcut('-')) {
-    for(unsigned int i = 0; i < graph.size(); i++)
-      for(unsigned int j = 0; j < graph[i]->gl.size(); j++)
+    for(std::size_t i = 0; i < graph.size(); i++)
+      for(std::size_t j = 0; j < graph[i]->gl.size(); j++)
         graph[i]->gl[j]->invertSelection = 1;
     status = 0; // trick: do as if we didn't use it
   }
@@ -773,12 +795,12 @@ int FlGui::testGlobalShortcuts(int event)
     }
     else {
       bool lasso = false;
-      for(unsigned int i = 0; i < graph.size(); i++)
-        for(unsigned int j = 0; j < graph[i]->gl.size(); j++)
+      for(std::size_t i = 0; i < graph.size(); i++)
+        for(std::size_t j = 0; j < graph[i]->gl.size(); j++)
           if(graph[i]->gl[j]->lassoMode) lasso = true;
       if(lasso) {
-        for(unsigned int i = 0; i < graph.size(); i++)
-          for(unsigned int j = 0; j < graph[i]->gl.size(); j++)
+        for(std::size_t i = 0; i < graph.size(); i++)
+          for(std::size_t j = 0; j < graph[i]->gl.size(); j++)
             graph[i]->gl[j]->lassoMode = false;
         status = 2;
       }
@@ -837,7 +859,7 @@ int FlGui::testGlobalShortcuts(int event)
     status = 2;
   }
   else if(Fl::test_shortcut(FL_ALT + 'i')) {
-    for(unsigned int i = 0; i < PView::list.size(); i++)
+    for(std::size_t i = 0; i < PView::list.size(); i++)
       if(opt_view_visible(i, GMSH_GET, 0))
         opt_view_show_scale(i, GMSH_SET | GMSH_GUI,
                             !opt_view_show_scale(i, GMSH_GET, 0));
@@ -849,7 +871,7 @@ int FlGui::testGlobalShortcuts(int event)
     status = 2;
   }
   else if(Fl::test_shortcut(FL_ALT + FL_SHIFT + 'c')) {
-    for(unsigned int i = 0; i < PView::list.size(); i++)
+    for(std::size_t i = 0; i < PView::list.size(); i++)
       if(opt_view_visible(i, GMSH_GET, 0))
         opt_view_colormap_number(i, GMSH_SET | GMSH_GUI,
                                  opt_view_colormap_number(i, GMSH_GET, 0) + 1);
@@ -859,7 +881,7 @@ int FlGui::testGlobalShortcuts(int event)
     opt_geometry_light(0, GMSH_SET | GMSH_GUI,
                        !opt_geometry_light(0, GMSH_GET, 0));
     opt_mesh_light(0, GMSH_SET | GMSH_GUI, !opt_mesh_light(0, GMSH_GET, 0));
-    for(unsigned int i = 0; i < PView::list.size(); i++)
+    for(std::size_t i = 0; i < PView::list.size(); i++)
       if(opt_view_visible(i, GMSH_GET, 0))
         opt_view_light(i, GMSH_SET | GMSH_GUI, !opt_view_light(i, GMSH_GET, 0));
     status = 2;
@@ -886,7 +908,7 @@ int FlGui::testGlobalShortcuts(int event)
   else if(Fl::test_shortcut(FL_ALT + 'a')) {
     opt_general_axes(0, GMSH_SET | GMSH_GUI,
                      opt_general_axes(0, GMSH_GET, 0) + 1);
-    for(unsigned int i = 0; i < PView::list.size(); i++)
+    for(std::size_t i = 0; i < PView::list.size(); i++)
       if(opt_view_visible(i, GMSH_GET, 0))
         opt_view_axes(i, GMSH_SET | GMSH_GUI,
                       opt_view_axes(i, GMSH_GET, 0) + 1);
@@ -955,7 +977,7 @@ int FlGui::testGlobalShortcuts(int event)
     status = 2;
   }
   else if(Fl::test_shortcut(FL_ALT + 't')) {
-    for(unsigned int i = 0; i < PView::list.size(); i++)
+    for(std::size_t i = 0; i < PView::list.size(); i++)
       if(opt_view_visible(i, GMSH_GET, 0)) {
         int t = opt_view_intervals_type(i, GMSH_GET, 0) + 1;
         if(t == 4) t = 1; // skip numeric display
@@ -964,21 +986,21 @@ int FlGui::testGlobalShortcuts(int event)
     status = 2;
   }
   else if(Fl::test_shortcut(FL_ALT + FL_SHIFT + 't')) {
-    for(unsigned int i = 0; i < PView::list.size(); i++)
+    for(std::size_t i = 0; i < PView::list.size(); i++)
       if(opt_view_visible(i, GMSH_GET, 0))
         opt_view_intervals_type(i, GMSH_SET | GMSH_GUI,
                                 opt_view_intervals_type(i, GMSH_GET, 0) + 1);
     status = 2;
   }
   else if(Fl::test_shortcut(FL_ALT + 'r')) {
-    for(unsigned int i = 0; i < PView::list.size(); i++)
+    for(std::size_t i = 0; i < PView::list.size(); i++)
       if(opt_view_visible(i, GMSH_GET, 0))
         opt_view_range_type(i, GMSH_SET | GMSH_GUI,
                             opt_view_range_type(i, GMSH_GET, 0) + 1);
     status = 2;
   }
   else if(Fl::test_shortcut(FL_ALT + 'n')) {
-    for(unsigned int i = 0; i < PView::list.size(); i++)
+    for(std::size_t i = 0; i < PView::list.size(); i++)
       if(opt_view_visible(i, GMSH_GET, 0))
         opt_view_draw_strings(i, GMSH_SET | GMSH_GUI,
                               !opt_view_draw_strings(i, GMSH_GET, 0));
@@ -986,7 +1008,7 @@ int FlGui::testGlobalShortcuts(int event)
   }
   else if(Fl::test_shortcut(FL_ALT + 'e') ||
           Fl::test_shortcut(FL_ALT + FL_SHIFT + 'e')) {
-    for(unsigned int i = 0; i < PView::list.size(); i++)
+    for(std::size_t i = 0; i < PView::list.size(); i++)
       if(opt_view_visible(i, GMSH_GET, 0))
         opt_view_show_element(i, GMSH_SET | GMSH_GUI,
                               !opt_view_show_element(i, GMSH_GET, 0));
@@ -994,7 +1016,7 @@ int FlGui::testGlobalShortcuts(int event)
   }
   else if(Fl::test_shortcut(FL_ALT + 'h')) {
     static int show = 0;
-    for(unsigned int i = 0; i < PView::list.size(); i++)
+    for(std::size_t i = 0; i < PView::list.size(); i++)
       opt_view_visible(i, GMSH_SET | GMSH_GUI, show);
     show = !show;
     status = 2;
@@ -1003,6 +1025,10 @@ int FlGui::testGlobalShortcuts(int event)
     status = 1;
   }
 
+#if defined(HAVE_TOUCHBAR)
+  updateTouchBar();
+#endif
+
   if(status == 2) {
     drawContext::global()->draw();
     return 1;
@@ -1050,7 +1076,7 @@ int FlGui::testArrowShortcuts()
 
 void FlGui::setGraphicTitle(const std::string &title)
 {
-  for(unsigned int i = 0; i < graph.size(); i++) {
+  for(std::size_t i = 0; i < graph.size(); i++) {
     std::ostringstream sstream;
     if(title.empty())
       sstream << "Gmsh";
@@ -1064,7 +1090,7 @@ void FlGui::setGraphicTitle(const std::string &title)
 
 void FlGui::updateViews(bool numberOfViewsHasChanged, bool deleteWidgets)
 {
-  for(unsigned int i = 0; i < graph.size(); i++) graph[i]->checkAnimButtons();
+  for(std::size_t i = 0; i < graph.size(); i++) graph[i]->checkAnimButtons();
   if(numberOfViewsHasChanged) {
     if(onelab) onelab->rebuildTree(deleteWidgets);
     options->resetBrowser();
@@ -1097,7 +1123,7 @@ openglWindow *FlGui::getCurrentOpenglWindow()
 void FlGui::splitCurrentOpenglWindow(char how)
 {
   openglWindow *g = getCurrentOpenglWindow();
-  for(unsigned int i = 0; i < graph.size(); i++) {
+  for(std::size_t i = 0; i < graph.size(); i++) {
     if(graph[i]->split(g, how)) break;
   }
 }
@@ -1188,7 +1214,7 @@ void FlGui::setStatus(const std::string &msg, bool opengl)
     }
     strncpy(buff, tmp.c_str(), sizeof(buff) - 1);
     buff[sizeof(buff) - 1] = '\0';
-    for(unsigned int i = 0; i < graph.size(); i++) {
+    for(std::size_t i = 0; i < graph.size(); i++) {
       graph[i]->getProgress()->label(buff);
       graph[i]->getProgress()->redraw();
     }
@@ -1211,7 +1237,7 @@ void FlGui::setStatus(const std::string &msg, bool opengl)
 
 void FlGui::setLastStatus(int col)
 {
-  for(unsigned int i = 0; i < graph.size(); i++) {
+  for(std::size_t i = 0; i < graph.size(); i++) {
     if(col >= 0 && graph[0]->getMessageHeight() < FL_NORMAL_SIZE) {
       if(CTX::instance()->guiColorScheme) // dark
         graph[i]->getProgress()->color(col);
@@ -1229,7 +1255,7 @@ void FlGui::setLastStatus(int col)
 void FlGui::setProgress(const std::string &msg, double val, double min,
                         double max)
 {
-  for(unsigned int i = 0; i < FlGui::instance()->graph.size(); i++) {
+  for(std::size_t i = 0; i < FlGui::instance()->graph.size(); i++) {
     if(FlGui::instance()->graph[i]->getProgress()->value() != val)
       FlGui::instance()->graph[i]->getProgress()->value(val);
     if(FlGui::instance()->graph[i]->getProgress()->minimum() != min)
@@ -1305,7 +1331,7 @@ void window_cb(Fl_Widget *w, void *data)
   std::string str((const char *)data);
 
   if(str == "minimize") {
-    for(unsigned int i = 0; i < FlGui::instance()->graph.size(); i++)
+    for(std::size_t i = 0; i < FlGui::instance()->graph.size(); i++)
       if(FlGui::instance()->graph[i]->getWindow()->shown())
         FlGui::instance()->graph[i]->getWindow()->iconize();
     if(FlGui::instance()->options->win->shown())
@@ -1347,25 +1373,27 @@ void window_cb(Fl_Widget *w, void *data)
       FlGui::instance()->fullscreen->resize(x, y, w, h);
       FlGui::instance()->fullscreen->valid(0);
       FlGui::instance()->fullscreen->show();
+      FlGui::instance()->fullscreen->fullscreen();
       while(!FlGui::instance()->fullscreen->valid()) FlGui::wait();
       FlGui::instance()->fullscreen->getDrawContext()->copyViewAttributes(
         FlGui::instance()->getCurrentOpenglWindow()->getDrawContext());
       openglWindow::setLastHandled(FlGui::instance()->fullscreen);
-      for(unsigned int i = 0; i < FlGui::instance()->graph.size(); i++)
+      for(std::size_t i = 0; i < FlGui::instance()->graph.size(); i++)
         FlGui::instance()->graph[i]->getWindow()->hide();
       drawContext::global()->draw();
       fullscreen = 1;
     }
     else {
-      for(unsigned int i = 0; i < FlGui::instance()->graph.size(); i++)
+      for(std::size_t i = 0; i < FlGui::instance()->graph.size(); i++)
         FlGui::instance()->graph[i]->gl[0]->valid(0);
-      for(unsigned int i = 0; i < FlGui::instance()->graph.size(); i++)
+      for(std::size_t i = 0; i < FlGui::instance()->graph.size(); i++)
         FlGui::instance()->graph[i]->getWindow()->show();
-      for(unsigned int i = 0; i < FlGui::instance()->graph.size(); i++)
+      for(std::size_t i = 0; i < FlGui::instance()->graph.size(); i++)
         while(!FlGui::instance()->graph[i]->gl[0]->valid()) FlGui::wait();
       FlGui::instance()->graph[0]->gl[0]->getDrawContext()->copyViewAttributes(
         FlGui::instance()->getCurrentOpenglWindow()->getDrawContext());
       openglWindow::setLastHandled(FlGui::instance()->graph[0]->gl[0]);
+      FlGui::instance()->fullscreen->fullscreen_off();
       FlGui::instance()->fullscreen->hide();
       drawContext::global()->draw();
       fullscreen = 0;
@@ -1373,7 +1401,7 @@ void window_cb(Fl_Widget *w, void *data)
   }
   else if(str == "front") {
     // the order is important!
-    for(unsigned int i = 0; i < FlGui::instance()->graph.size(); i++)
+    for(std::size_t i = 0; i < FlGui::instance()->graph.size(); i++)
       FlGui::instance()->graph[i]->getWindow()->show();
     if(FlGui::instance()->options->win->shown())
       FlGui::instance()->options->win->show();
@@ -1404,7 +1432,7 @@ void window_cb(Fl_Widget *w, void *data)
 
 void FlGui::addMessage(const char *msg)
 {
-  for(unsigned int i = 0; i < FlGui::instance()->graph.size(); i++) {
+  for(std::size_t i = 0; i < FlGui::instance()->graph.size(); i++) {
     FlGui::instance()->graph[i]->addMessage(msg);
   }
 }
