@@ -35,6 +35,7 @@
 #include "PView.h"
 #include "PViewOptions.h"
 #include <iostream>
+
 // File chooser
 
 #if defined(HAVE_NATIVE_FILE_CHOOSER)
@@ -269,13 +270,13 @@ int genericBitmapFileDialog(const char *name, const char *title, int format)
     dialog->v[0] = new Fl_Value_Input(WB, y, BB / 2, BH);
     dialog->v[0]->minimum(-1);
     dialog->v[0]->maximum(5000);
-    dialog->v[0]->step(1);
+    if(CTX::instance()->inputScrolling) dialog->v[0]->step(1);
     dialog->v[1] =
       new Fl_Value_Input(WB + BB / 2, y, BB - BB / 2, BH, "Dimensions");
     y += BH;
     dialog->v[1]->minimum(-1);
     dialog->v[1]->maximum(5000);
-    dialog->v[1]->step(1);
+    if(CTX::instance()->inputScrolling) dialog->v[1]->step(1);
     dialog->v[1]->align(FL_ALIGN_RIGHT);
     dialog->s[0] = new Fl_Value_Slider(WB, y, BB, BH, "Quality");
     y += BH;
@@ -283,14 +284,14 @@ int genericBitmapFileDialog(const char *name, const char *title, int format)
     dialog->s[0]->align(FL_ALIGN_RIGHT);
     dialog->s[0]->minimum(1);
     dialog->s[0]->maximum(100);
-    dialog->s[0]->step(1);
+    if(CTX::instance()->inputScrolling) dialog->s[0]->step(1);
     dialog->s[1] = new Fl_Value_Slider(WB, y, BB, BH, "Smoothing");
     y += BH;
     dialog->s[1]->type(FL_HOR_SLIDER);
     dialog->s[1]->align(FL_ALIGN_RIGHT);
     dialog->s[1]->minimum(0);
     dialog->s[1]->maximum(100);
-    dialog->s[1]->step(1);
+    if(CTX::instance()->inputScrolling) dialog->s[1]->step(1);
     dialog->ok = new Fl_Return_Button(WB, y + WB, BB, BH, "OK");
     dialog->cancel = new Fl_Button(2 * WB + BB, y + WB, BB, BH, "Cancel");
     dialog->window->end();
@@ -379,13 +380,13 @@ int pgfBitmapFileDialog(const char *name, const char *title, int format)
     dialog->v[0] = new Fl_Value_Input(WB, y, BB / 2, BH);
     dialog->v[0]->minimum(-1);
     dialog->v[0]->maximum(5000);
-    dialog->v[0]->step(1);
+    if(CTX::instance()->inputScrolling) dialog->v[0]->step(1);
     dialog->v[1] =
       new Fl_Value_Input(WB + BB / 2, y, BB - BB / 2, BH, "Dimensions");
     y += BH;
     dialog->v[1]->minimum(-1);
     dialog->v[1]->maximum(5000);
-    dialog->v[1]->step(1);
+    if(CTX::instance()->inputScrolling) dialog->v[1]->step(1);
     dialog->v[1]->align(FL_ALIGN_RIGHT);
     dialog->ok = new Fl_Return_Button(WB, y + WB, BB, BH, "OK");
     dialog->cancel = new Fl_Button(2 * WB + BB, y + WB, BB, BH, "Cancel");
@@ -537,7 +538,7 @@ int mpegFileDialog(const char *name)
     dialog->v[4]->align(FL_ALIGN_RIGHT);
     dialog->v[4]->minimum(1);
     dialog->v[4]->maximum(500);
-    dialog->v[4]->step(1);
+    if(CTX::instance()->inputScrolling) dialog->v[4]->step(1);
     y += BH;
     dialog->param->end();
 
@@ -548,7 +549,7 @@ int mpegFileDialog(const char *name)
     y += BH;
     dialog->v[0]->minimum(1. / 30.);
     dialog->v[0]->maximum(2.);
-    dialog->v[0]->step(1. / 30.);
+    if(CTX::instance()->inputScrolling) dialog->v[0]->step(1. / 30.);
     dialog->v[0]->precision(3);
     dialog->v[0]->align(FL_ALIGN_RIGHT);
 
@@ -556,7 +557,7 @@ int mpegFileDialog(const char *name)
     y += BH;
     dialog->v[1]->minimum(1);
     dialog->v[1]->maximum(100);
-    dialog->v[1]->step(1);
+    if(CTX::instance()->inputScrolling) dialog->v[1]->step(1);
     dialog->v[1]->align(FL_ALIGN_RIGHT);
 
     dialog->c[0] = new Fl_Check_Button(WB, y, ww, BH, "Print background");
@@ -1144,7 +1145,7 @@ int mshFileDialog(const char *name)
           0, GMSH_SET | GMSH_GUI,
           (dialog->c->value() == 0) ?
             1.0 :
-            (dialog->c->value() == 1 || dialog->c->value() == 2) ? 2.2 : 4.0);
+            (dialog->c->value() == 1 || dialog->c->value() == 2) ? 2.2 : 4.1);
         opt_mesh_binary(
           0, GMSH_SET | GMSH_GUI,
           (dialog->c->value() == 2 || dialog->c->value() == 4) ? 1 : 0);
@@ -1424,6 +1425,97 @@ int bdfFileDialog(const char *name)
 
 // Generic mesh dialog
 
+int stlFileDialog(const char *name)
+{
+  struct _stlFileDialog {
+    Fl_Window *window;
+    Fl_Choice *c[2];
+    Fl_Check_Button *b;
+    Fl_Button *ok, *cancel;
+  };
+  static _stlFileDialog *dialog = NULL;
+
+  static Fl_Menu_Item formatmenu[] = {
+    {"ASCII", 0, 0, 0},
+    {"Binary", 0, 0, 0},
+    {0}
+  };
+  static Fl_Menu_Item solidmenu[] = {
+    {"Single", 0, 0, 0},
+    {"Per surface", 0, 0, 0},
+    {"Per physical surface", 0, 0, 0},
+    {0}
+  };
+
+  int BBB = BB + 9; // labels too long
+
+  if(!dialog) {
+    dialog = new _stlFileDialog;
+    int h = 3 * WB + 4 * BH, w = 2 * BBB + 3 * WB, y = WB;
+    dialog->window = new Fl_Double_Window(w, h, "STL Options");
+    dialog->window->box(GMSH_WINDOW_BOX);
+    dialog->window->set_modal();
+    dialog->c[0] = new Fl_Choice(WB, y, BBB + BBB / 4, BH, "Format");
+    y += BH;
+    dialog->c[0]->menu(formatmenu);
+    dialog->c[0]->align(FL_ALIGN_RIGHT);
+    dialog->b = new Fl_Check_Button
+      (WB, y, 2 * BBB + WB, BH, "Save all elements");
+    y += BH;
+    dialog->b->type(FL_TOGGLE_BUTTON);
+    dialog->c[1] = new Fl_Choice(WB, y, BBB + BBB / 4, BH, "Solid");
+    y += BH;
+    dialog->c[1]->menu(solidmenu);
+    dialog->c[1]->align(FL_ALIGN_RIGHT);
+    dialog->ok = new Fl_Return_Button(WB, y + WB, BBB, BH, "OK");
+    dialog->cancel = new Fl_Button(2 * WB + BBB, y + WB, BBB, BH, "Cancel");
+    dialog->window->end();
+    dialog->window->hotspot(dialog->window);
+  }
+
+  dialog->c[0]->value(CTX::instance()->mesh.binary ? 1 : 0);
+  dialog->b->value(CTX::instance()->mesh.saveAll ? 1 : 0);
+  dialog->c[1]->value(CTX::instance()->mesh.stlOneSolidPerSurface == 2 ? 2 :
+                      CTX::instance()->mesh.stlOneSolidPerSurface == 1 ? 1 :0);
+
+  if(dialog->c[1]->value() == 2)
+    dialog->b->deactivate();
+  else
+    dialog->b->activate();
+
+  dialog->window->show();
+
+  while(dialog->window->shown()) {
+    Fl::wait();
+    for(;;) {
+      Fl_Widget *o = Fl::readqueue();
+      if(!o) break;
+      if(o == dialog->c[1]) {
+        if(dialog->c[1]->value() == 2)
+          dialog->b->deactivate();
+        else
+          dialog->b->activate();
+      }
+      if(o == dialog->ok) {
+        opt_mesh_binary(0, GMSH_SET | GMSH_GUI, dialog->c[0]->value());
+        opt_mesh_save_all(0, GMSH_SET | GMSH_GUI, dialog->b->value() ? 1 : 0);
+        opt_mesh_stl_one_solid_per_surface(0, GMSH_SET | GMSH_GUI,
+                                           dialog->c[1]->value());
+        CreateOutputFile(name, FORMAT_STL);
+        dialog->window->hide();
+        return 1;
+      }
+      if(o == dialog->window || o == dialog->cancel) {
+        dialog->window->hide();
+        return 0;
+      }
+    }
+  }
+  return 0;
+}
+
+// Generic mesh dialog
+
 int genericMeshFileDialog(const char *name, const char *title, int format,
                           bool binary_support, bool element_tag_support)
 {
@@ -1524,12 +1616,12 @@ static void _saveViews(const std::string &name, int which, int format,
   }
   else if(which == 1) {
     int numVisible = 0;
-    for(unsigned int i = 0; i < PView::list.size(); i++)
+    for(std::size_t i = 0; i < PView::list.size(); i++)
       if(PView::list[i]->getOptions()->visible) numVisible++;
     if(!numVisible) { Msg::Error("No visible view"); }
     else {
       bool first = true;
-      for(unsigned int i = 0; i < PView::list.size(); i++) {
+      for(std::size_t i = 0; i < PView::list.size(); i++) {
         if(PView::list[i]->getOptions()->visible) {
           std::string fileName = name;
           if(!canAppend && numVisible > 1) {
@@ -1544,7 +1636,7 @@ static void _saveViews(const std::string &name, int which, int format,
     }
   }
   else {
-    for(unsigned int i = 0; i < PView::list.size(); i++) {
+    for(std::size_t i = 0; i < PView::list.size(); i++) {
       std::string fileName = name;
       if(!canAppend && PView::list.size() > 1) {
         std::ostringstream os;
@@ -1640,12 +1732,12 @@ static void _saveAdaptedViews(const std::string &name, int useDefaultName,
   }
   else if(which == 1) {
     int numVisible = 0;
-    for(unsigned int i = 0; i < PView::list.size(); i++)
+    for(std::size_t i = 0; i < PView::list.size(); i++)
       if(PView::list[i]->getOptions()->visible) numVisible++;
     if(!numVisible) { Msg::Error("No visible view"); }
     else {
       bool first = true;
-      for(unsigned int i = 0; i < PView::list.size(); i++) {
+      for(std::size_t i = 0; i < PView::list.size(); i++) {
         if(PView::list[i]->getOptions()->visible) {
           std::string fileName = name;
           if(!canAppend && numVisible > 1) {
@@ -1662,7 +1754,7 @@ static void _saveAdaptedViews(const std::string &name, int useDefaultName,
     }
   }
   else {
-    for(unsigned int i = 0; i < PView::list.size(); i++) {
+    for(std::size_t i = 0; i < PView::list.size(); i++) {
       std::string fileName = name;
       if(!canAppend && PView::list.size() > 1) {
         std::ostringstream os;
@@ -1713,7 +1805,7 @@ int pvtuAdaptFileDialog(const char *name)
     dialog->vi[0]->align(FL_ALIGN_RIGHT);
     dialog->vi[0]->minimum(0);
     dialog->vi[0]->maximum(6);
-    dialog->vi[0]->step(1);
+    if(CTX::instance()->inputScrolling) dialog->vi[0]->step(1);
     dialog->vi[0]->value(1);
     dialog->vi[0]->when(FL_WHEN_RELEASE);
 
@@ -1722,7 +1814,7 @@ int pvtuAdaptFileDialog(const char *name)
     dialog->vi[1]->align(FL_ALIGN_RIGHT);
     dialog->vi[1]->minimum(-1.e-4);
     dialog->vi[1]->maximum(0.1);
-    dialog->vi[1]->step(1.e-4);
+    if(CTX::instance()->inputScrolling) dialog->vi[1]->step(1.e-4);
     dialog->vi[1]->value(-1.e-4);
     dialog->vi[1]->when(FL_WHEN_RELEASE);
 
@@ -1731,7 +1823,7 @@ int pvtuAdaptFileDialog(const char *name)
     dialog->vi[2]->align(FL_ALIGN_RIGHT);
     dialog->vi[2]->minimum(1);
     dialog->vi[2]->maximum(262144);
-    dialog->vi[2]->step(1);
+    if(CTX::instance()->inputScrolling) dialog->vi[2]->step(1);
     dialog->vi[2]->value(4);
     dialog->vi[2]->when(FL_WHEN_RELEASE);
 
@@ -1821,13 +1913,13 @@ int x3dViewFileDialog(const char *name, const char *title, int format)
     dialog->input[0]->align(FL_ALIGN_RIGHT);
     dialog->input[0]->minimum(-16);
     dialog->input[0]->maximum(16);
-    dialog->input[0]->step(.25);
+    if(CTX::instance()->inputScrolling) dialog->input[0]->step(.25);
     dialog->input[1] = new Fl_Value_Input(WB, y, BB, BH, "Transparency");
     y += BH;
     dialog->input[1]->align(FL_ALIGN_RIGHT);
     dialog->input[1]->minimum(0.);
     dialog->input[1]->maximum(1.);
-    dialog->input[1]->step(0.05);
+    if(CTX::instance()->inputScrolling) dialog->input[1]->step(0.05);
     dialog->e[1] = new Fl_Check_Button(WB, y, w - 2 * WB, BH,
                                        "High compatibility (no scale)");
     y += BH;
