@@ -7,8 +7,8 @@
 
 // FIXME: the contents of this file will be removed in a future release of Gmsh.
 
-#ifndef _CGNS_UTILS_H_
-#define _CGNS_UTILS_H_
+#ifndef CGNS_UTILS_H
+#define CGNS_UTILS_H
 
 #include <map>
 #include <vector>
@@ -23,6 +23,14 @@
 #include "MFaceHash.h"
 #include "GmshMessage.h"
 
+// FIXME: This code is faaaar too complicated for what it does - as is the whole
+// CGNS mess. Until we rewrite this whole thing, let's quiet GCC about the
+// reinterpret_casts dereferencing type-punned pointer, which will break
+// strict-aliasing rules:
+
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wstrict-aliasing"
+
 /*******************************************************************************
  *
  * This lightweight pool class attempts to reduce memory usage by having the
@@ -551,6 +559,7 @@ namespace CCon // "Custom Container"
 
 } // End of namespace CCon
 
+#pragma GCC diagnostic pop
 
 /*******************************************************************************
  *
@@ -1082,8 +1091,8 @@ public:
         itBoV != itEnd; ++itBoV) {
       // ... clear the faces
       GlobalVertexData<FaceT> &ref = itBoV->second;
-      size_t nf = ref.faces.size();
-      for(unsigned int i = 0; i < nf; ++i) {
+      std::size_t nf = ref.faces.size();
+      for(std::size_t i = 0; i < nf; ++i) {
         ++icount;
         FaceT *p = ref.faces[i].face;
         if(p) {
