@@ -11,6 +11,7 @@
 #include "GModel.h"
 #include "discreteFace.h"
 #include "discreteEdge.h"
+#include "discreteVertex.h"
 #include "MPoint.h"
 #include "MVertex.h"
 #include "MLine.h"
@@ -29,11 +30,17 @@
 
 bool topoExists(GModel *gm)
 {
-  std::vector<GEntity *> entities;
-  gm->getEntities(entities);
-  std::set<MVertex *> vs;
-  for(unsigned int i = 0; i < entities.size(); i++) {
-    if(entities[i]->vertices().empty()) return false;
+  for(GModel::eiter it = gm->firstEdge(); it != gm->lastEdge(); it++) {
+    GEdge *ge = *it;
+    if(!ge->getBeginVertex() || !ge->getEndVertex()) return false;
+  }
+  for(GModel::fiter it = gm->firstFace(); it != gm->lastFace(); it++) {
+    GFace *gf = *it;
+    if(gf->edges().empty()) return false;
+  }
+  for(GModel::riter it = gm->firstRegion(); it != gm->lastRegion(); it++) {
+    GRegion *gr = *it;
+    if(gr->faces().empty()) return false;
   }
   return true;
 }
@@ -48,7 +55,7 @@ std::vector<GEdge *> ensureSimplyConnectedEdge(GEdge *ge)
   _all.push_back(ge);
 
   // create vertex to edge connectivity : only To neighbors are considered ...
-  for(unsigned int i = 0; i < ge->lines.size(); i++) {
+  for(std::size_t i = 0; i < ge->lines.size(); i++) {
     _lines.insert(ge->lines[i]);
     for(int j = 0; j < 2; j++) {
       std::map<MVertex *, std::pair<MLine *, MLine *> >::iterator it =
@@ -71,9 +78,7 @@ std::vector<GEdge *> ensureSimplyConnectedEdge(GEdge *ge)
       _stack.pop();
       _lines.erase(l);
       // avoid adding twice the last one
-      if(!_part.size() || _part[_part.size() - 1] != l) {
-        _part.push_back(l);
-      }
+      if(!_part.size() || _part[_part.size() - 1] != l) { _part.push_back(l); }
       for(int j = 0; j < 2; j++) {
         std::map<MVertex *, std::pair<MLine *, MLine *> >::iterator it =
           _conn.find(l->getVertex(j));
@@ -92,7 +97,7 @@ std::vector<GEdge *> ensureSimplyConnectedEdge(GEdge *ge)
 
   if(_parts.size() <= 1) return _all;
 
-  Msg::Info("Edge %d is not simply connected: splitting it in %d parts",
+  Msg::Info("Curve %d is not simply connected: splitting it in %d parts",
             ge->tag(), _parts.size());
 
   for(size_t i = 0; i < _parts.size(); i++) {
@@ -128,7 +133,7 @@ void ensureManifoldFace(GFace *gf)
 
   std::set<MElement *> _allFaces;
 
-  for(unsigned int i = 0; i < gf->getNumMeshElements(); i++) {
+  for(std::size_t i = 0; i < gf->getNumMeshElements(); i++) {
     MElement *e = gf->getMeshElement(i);
     _allFaces.insert(e);
     for(int j = 0; j < e->getNumEdges(); j++) {
@@ -140,9 +145,7 @@ void ensureManifoldFace(GFace *gf)
           _pairs[ed] = std::make_pair(e, (MElement *)NULL);
         }
         else {
-          if(it->second.second == NULL) {
-            it->second.second = e;
-          }
+          if(it->second.second == NULL) { it->second.second = e; }
           else {
             _nonManifold.insert(ed);
             _pairs.erase(it);
@@ -179,10 +182,10 @@ void ensureManifoldFace(GFace *gf)
     _sub.push_back(_f);
   }
 
-  Msg::Info("Face %d is non-manifold: splitting it in %d parts", gf->tag(),
+  Msg::Info("Surface %d is non-manifold: splitting it in %d parts", gf->tag(),
             _sub.size());
 
-  for(unsigned int i = 0; i < _sub.size(); i++) {
+  for(std::size_t i = 0; i < _sub.size(); i++) {
     if(i == 0)
       assignFace(gf, _sub[i]);
     else {
@@ -199,7 +202,7 @@ void ensureManifoldFaces(GModel *gm)
   std::vector<GFace *> f;
   for(GModel::fiter it = gm->firstFace(); it != gm->lastFace(); it++)
     f.push_back(*it);
-  for(unsigned int i = 0; i < f.size(); i++) ensureManifoldFace(f[i]);
+  for(std::size_t i = 0; i < f.size(); i++) ensureManifoldFace(f[i]);
 }
 
 typedef std::map<MVertex *, std::set<GEdge *> > MVertexToGEdgesMap;
@@ -218,9 +221,8 @@ void createTopologyFromMesh1D(GModel *gm, int &num)
     if(gv->mesh_vertices.size()) {
       MVertex *mv = gv->mesh_vertices[0];
       mVertexToGVertex[mv] = gv;
-      Msg::Info(
-        "The mesh contains already topological vertex %i containing vertex %i",
-        gv->tag(), mv->getNum());
+      Msg::Info("The model already has point %i, containing node %i",
+                gv->tag(), mv->getNum());
     }
   }
 
@@ -232,7 +234,7 @@ void createTopologyFromMesh1D(GModel *gm, int &num)
 
   for(GModel::eiter it = gm->firstEdge(); it != gm->lastEdge(); it++) {
     GEdge *ge = *it;
-    for(unsigned int i = 0; i < (*it)->lines.size(); i++) {
+    for(std::size_t i = 0; i < (*it)->lines.size(); i++) {
       MLine *e = (*it)->lines[i];
       for(int j = 0; j < 2; j++) {
         MVertex *mv = e->getVertex(j);
@@ -258,9 +260,8 @@ void createTopologyFromMesh1D(GModel *gm, int &num)
       if(gEdgesToGVertex.find(gEdges) == gEdgesToGVertex.end()) {
         num++;
 
-        discreteVertex *dv =
-          new discreteVertex(gm, gm->getMaxElementaryNumber(0) + 1,
-                             mv->x(), mv->y(), mv->z());
+        discreteVertex *dv = new discreteVertex(
+          gm, gm->getMaxElementaryNumber(0) + 1, mv->x(), mv->y(), mv->z());
         gm->add(dv);
 
         mVertexToGVertex[mv] = dv;
@@ -281,6 +282,7 @@ void createTopologyFromMesh1D(GModel *gm, int &num)
 
   // link all GEdge to GVertex and vice versa
   // we expect to see two GVertex per GEdge
+  // unless it is periodic !!!!
 
   for(GEdgeToGVerticesMap::iterator gEIter = gEdgeToGVertices.begin();
       gEIter != gEdgeToGVertices.end(); ++gEIter) {
@@ -300,8 +302,13 @@ void createTopologyFromMesh1D(GModel *gm, int &num)
 
     else {
       std::vector<GEdge *> splits = ensureSimplyConnectedEdge(ge);
-
-      if(splits.size() == 1) {
+      if(splits.size() == 1) { // periodic case
+        GVertex *gv1 = *(gVerts.begin());
+        ge->setBeginVertex(gv1);
+        ge->setEndVertex(gv1);
+        gv1->addEdge(ge);
+      }
+      else {
         std::ostringstream gVertexList;
         for(std::set<GVertex *>::iterator gvIter = gVerts.begin();
             gvIter != gVerts.end(); ++gvIter) {
@@ -318,12 +325,11 @@ void createTopologyFromMesh1D(GModel *gm, int &num)
   // we still need to check this is actually the case ...
 
   for(GModel::eiter it = gm->firstEdge(); it != gm->lastEdge(); it++) {
-    if(!(*it)->getBeginVertex() && !(*it)->getEndVertex()) {
+    if(!(*it)->getBeginVertex() || !(*it)->getEndVertex()) {
       num++;
       MVertex *v = (*it)->lines[0]->getVertex(0);
-      discreteVertex *dv =
-        new discreteVertex(gm, gm->getMaxElementaryNumber(0) + 1,
-                           v->x(), v->y(), v->z());
+      discreteVertex *dv = new discreteVertex(
+        gm, gm->getMaxElementaryNumber(0) + 1, v->x(), v->y(), v->z());
       gm->add(dv);
       MPoint *mp = new MPoint(v);
       dv->points.push_back(mp);
@@ -378,7 +384,7 @@ void createTopologyFromMesh2D(GModel *gm, int &num)
 
   for(GModel::eiter it = gm->firstEdge(); it != gm->lastEdge(); it++) {
     GEdge *ge = *it;
-    for(unsigned int i = 0; i < (*it)->lines.size(); i++) {
+    for(std::size_t i = 0; i < (*it)->lines.size(); i++) {
       topoEdge te(ge->lines[i], 0);
       tEdgeToGEdge[te] = ge;
     }
@@ -391,7 +397,7 @@ void createTopologyFromMesh2D(GModel *gm, int &num)
 
   for(GModel::fiter it = gm->firstFace(); it != gm->lastFace(); it++) {
     GFace *gf = *it;
-    for(unsigned int i = 0; i < (*it)->getNumMeshElements(); i++) {
+    for(std::size_t i = 0; i < (*it)->getNumMeshElements(); i++) {
       MElement *e = (*it)->getMeshElement(i);
       if(e->getDim() == 2) {
         for(int j = 0; j < e->getNumEdges(); j++) {
@@ -416,7 +422,6 @@ void createTopologyFromMesh2D(GModel *gm, int &num)
 
   for(it = tEdgeToGFaces.begin(); it != tEdgeToGFaces.end(); ++it) {
     std::set<GFace *> &gfaces = it->second;
-
     if(gfaces.size() > 1) {
       GFacesToGEdgeMap::iterator gfIter = gFacesToGEdge.find(gfaces);
 
@@ -695,12 +700,12 @@ void GModel::createTopologyFromMeshNew()
   if(dim >= 2) createTopologyFromMesh2D(this, numE);
   if(dim >= 1) createTopologyFromMesh1D(this, numV);
 
-  _associateEntityWithMeshVertices();
+  _associateEntityWithMeshVertices(true); // force
 
   std::vector<GEntity *> entities;
   getEntities(entities);
   std::set<MVertex *> vs;
-  for(unsigned int i = 0; i < entities.size(); i++) {
+  for(std::size_t i = 0; i < entities.size(); i++) {
     vs.insert(entities[i]->mesh_vertices.begin(),
               entities[i]->mesh_vertices.end());
     entities[i]->mesh_vertices.clear();
