@@ -3,8 +3,8 @@
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _MHEXAHEDRON_H_
-#define _MHEXAHEDRON_H_
+#ifndef MHEXAHEDRON_H
+#define MHEXAHEDRON_H
 
 #include "MElement.h"
 
@@ -210,6 +210,18 @@ public:
     return e[face][edge];
   }
   virtual int numCommonNodesInDualGraph(const MElement *const other) const;
+  virtual int getVertexSolin(int numEdge, int numVertex){
+    static const int eSolin[12][2] =  {{0, 1}, {0, 3}, {0, 4}, {1, 2},
+                                 {1, 5}, {3, 2}, {2, 6}, {3, 7},
+                                 {4, 5}, {4, 7}, {5, 6}, {7, 6}};
+    return getVertex(eSolin[numEdge][numVertex])->getNum();
+  }
+  virtual MFace getFaceSolin(int numFace){
+    static const int fSolin[6][4] = {{0, 1, 3, 2}, {0, 1, 4, 5}, {0, 3, 4, 7},
+                                {1, 2, 5, 6}, {3, 2, 7, 6}, {4, 5, 7, 6}};
+    return MFace(_v[fSolin[numFace][0]], _v[fSolin[numFace][1]],
+                 _v[fSolin[numFace][2]], _v[fSolin[numFace][3]]);
+  }
 };
 
 /*
@@ -596,7 +608,7 @@ public:
     : MHexahedron(v0, v1, v2, v3, v4, v5, v6, v7, num, part), _order(order),
       _vs(v)
   {
-    for(unsigned int i = 0; i < _vs.size(); i++)
+    for(std::size_t i = 0; i < _vs.size(); i++)
       _vs[i]->setPolynomialOrder(_order);
   }
   MHexahedronN(const std::vector<MVertex *> &v, char order, int num = 0,
@@ -604,8 +616,8 @@ public:
     : MHexahedron(v[0], v[1], v[2], v[3], v[4], v[5], v[6], v[7], num, part),
       _order(order)
   {
-    for(unsigned int i = 8; i < v.size(); i++) _vs.push_back(v[i]);
-    for(unsigned int i = 0; i < _vs.size(); i++)
+    for(std::size_t i = 8; i < v.size(); i++) _vs.push_back(v[i]);
+    for(std::size_t i = 0; i < _vs.size(); i++)
       _vs[i]->setPolynomialOrder(_order);
   }
   ~MHexahedronN() {}
@@ -703,7 +715,7 @@ public:
     if(_order == 8 && _vs.size() + 8 == 92) return MSH_HEX_92;
     if(_order == 9 && _vs.size() + 8 == 104) return MSH_HEX_104;
 
-    Msg::Error("no tag matches a p%d hexahedron with %d vertices", _order,
+    Msg::Error("No MSH type found for P%d hexahedron with %d nodes", _order,
                8 + _vs.size());
     return 0;
   }
