@@ -23,7 +23,7 @@ double angle3Vertices(const MVertex *p1, const MVertex *p2, const MVertex *p3)
   return std::atan2(sinA, cosA);
 }
 
-MVertex::MVertex(double x, double y, double z, GEntity *ge, int num)
+MVertex::MVertex(double x, double y, double z, GEntity *ge, std::size_t num)
   : _visible(1), _order(1), _x(x), _y(y), _z(z), _ge(ge)
 {
 #if defined(_OPENMP)
@@ -40,7 +40,7 @@ MVertex::MVertex(double x, double y, double z, GEntity *ge, int num)
       m->setMaxVertexNumber(m->getMaxVertexNumber() + 1);
       _num = m->getMaxVertexNumber();
     }
-    _index = num;
+    _index = (long int)num;
   }
 }
 
@@ -57,7 +57,7 @@ void MVertex::deleteLast()
   }
 }
 
-void MVertex::forceNum(int num)
+void MVertex::forceNum(std::size_t num)
 {
 #if defined(_OPENMP)
 #pragma omp critical
@@ -75,11 +75,12 @@ void MVertex::writeMSH(FILE *fp, bool binary, bool saveParametric,
   if(_index < 0) return; // negative index vertices are never saved
 
   if(!binary) {
-    fprintf(fp, "%d %.16g %.16g %.16g ", _index, x() * scalingFactor,
+    fprintf(fp, "%ld %.16g %.16g %.16g ", _index, x() * scalingFactor,
             y() * scalingFactor, z() * scalingFactor);
   }
   else {
-    fwrite(&_index, sizeof(int), 1, fp);
+    int i = (int)_index;
+    fwrite(&i, sizeof(int), 1, fp);
     double data[3] = {x() * scalingFactor, y() * scalingFactor,
                       z() * scalingFactor};
     fwrite(data, sizeof(double), 3, fp);
@@ -154,14 +155,15 @@ void MVertex::writeMSH2(FILE *fp, bool binary, bool saveParametric,
 
   if(!binary) {
     if(!saveParametric)
-      fprintf(fp, "%d %.16g %.16g %.16g\n", _index, x() * scalingFactor,
+      fprintf(fp, "%ld %.16g %.16g %.16g\n", _index, x() * scalingFactor,
               y() * scalingFactor, z() * scalingFactor);
     else
-      fprintf(fp, "%d %.16g %.16g %.16g %d %d", _index, x() * scalingFactor,
+      fprintf(fp, "%ld %.16g %.16g %.16g %d %d", _index, x() * scalingFactor,
               y() * scalingFactor, z() * scalingFactor, myDim, myTag);
   }
   else {
-    fwrite(&_index, sizeof(int), 1, fp);
+    int i = (int)_index;
+    fwrite(&i, sizeof(int), 1, fp);
     double data[3] = {x() * scalingFactor, y() * scalingFactor,
                       z() * scalingFactor};
     fwrite(data, sizeof(double), 3, fp);
@@ -196,53 +198,6 @@ void MVertex::writeMSH2(FILE *fp, bool binary, bool saveParametric,
   }
 }
 
-void MVertex::writeMSH4(FILE *fp, bool binary, bool saveParametric,
-                        double scalingFactor)
-{
-  if(binary) {
-    fwrite(&_num, sizeof(int), 1, fp);
-    double xScale = _x * scalingFactor;
-    double yScale = _y * scalingFactor;
-    double zScale = _z * scalingFactor;
-    fwrite(&xScale, sizeof(double), 1, fp);
-    fwrite(&yScale, sizeof(double), 1, fp);
-    fwrite(&zScale, sizeof(double), 1, fp);
-    if(saveParametric) {
-      if(_ge->dim() == 1) {
-        double u;
-        getParameter(0, u);
-        fwrite(&u, sizeof(double), 1, fp);
-      }
-      else if(_ge->dim() == 2) {
-        double u, v;
-        getParameter(0, u);
-        getParameter(1, v);
-        fwrite(&u, sizeof(double), 1, fp);
-        fwrite(&v, sizeof(double), 1, fp);
-      }
-    }
-  }
-  else {
-    fprintf(fp, "%d %.16g %.16g %.16g", _num, _x * scalingFactor,
-            _y * scalingFactor, _z * scalingFactor);
-    if(saveParametric) {
-      if(_ge->dim() == 1) {
-        double u;
-        getParameter(0, u);
-        fprintf(fp, " %.16g", u);
-      }
-      else if(_ge->dim() == 2) {
-        double u, v;
-        getParameter(0, u);
-        getParameter(1, v);
-        fprintf(fp, " %.16g %.16g", u, v);
-      }
-    }
-
-    fprintf(fp, "\n");
-  }
-}
-
 void MVertex::writePLY2(FILE *fp)
 {
   if(_index < 0) return; // negative index vertices are never saved
@@ -265,7 +220,7 @@ void MVertex::writeUNV(FILE *fp, bool officialExponentFormat, double scalingFact
   int coord_sys = 1;
   int displacement_coord_sys = 1;
   int color = 11;
-  fprintf(fp, "%10d%10d%10d%10d\n", _index, coord_sys, displacement_coord_sys,
+  fprintf(fp, "%10ld%10d%10d%10d\n", _index, coord_sys, displacement_coord_sys,
           color);
 
   if(officialExponentFormat){
@@ -273,7 +228,7 @@ void MVertex::writeUNV(FILE *fp, bool officialExponentFormat, double scalingFact
     char tmp[128];
     sprintf(tmp, "%25.16E%25.16E%25.16E\n", x() * scalingFactor,
             y() * scalingFactor, z() * scalingFactor);
-    for(unsigned int i = 0; i < strlen(tmp); i++)
+    for(std::size_t i = 0; i < strlen(tmp); i++)
       if(tmp[i] == 'E') tmp[i] = 'D';
     fprintf(fp, "%s", tmp);
   }
@@ -306,8 +261,7 @@ void MVertex::writeMATLAB(FILE *fp, int filetype, bool binary,
 {
   if(_index < 0) return; // negative index vertices are never saved
   if(binary) {
-    Msg::Warning(
-      "Binary format not available for Matlab, saving into ASCII format");
+    Msg::Warning("Binary format not available for Matlab, saving in ASCII");
     binary = false;
   }
   fprintf(fp, "%.16g %.16g %.16g;\n", x() * scalingFactor, y() * scalingFactor,
@@ -318,15 +272,15 @@ void MVertex::writeTOCHNOG(FILE *fp, int dim, double scalingFactor)
 {
   if(_index < 0) return; // negative index vertices are never saved
   if(dim == 2) {
-    fprintf(fp, "node %d %.16g %.16g\n", _index, x() * scalingFactor,
+    fprintf(fp, "node %ld %.16g %.16g\n", _index, x() * scalingFactor,
             y() * scalingFactor);
   }
   else if(dim == 3) {
-    fprintf(fp, "node %d %.16g %.16g %.16g\n", _index, x() * scalingFactor,
+    fprintf(fp, "node %ld %.16g %.16g %.16g\n", _index, x() * scalingFactor,
             y() * scalingFactor, z() * scalingFactor);
   }
   else if(dim == 1) {
-    fprintf(fp, "node %d %.16g\n", _index, x() * scalingFactor);
+    fprintf(fp, "node %ld %.16g\n", _index, x() * scalingFactor);
   }
   else {
     fprintf(fp, "ERROR -- unsupported dimension: %d\n", dim);
@@ -348,14 +302,14 @@ void MVertex::writeNEU(FILE *fp, int dim, double scalingFactor)
 
   switch(dim) {
   case 3:
-    fprintf(fp, "%10d%20.11e%20.11e%20.11e\n", _index, x() * scalingFactor,
+    fprintf(fp, "%10ld%20.11e%20.11e%20.11e\n", _index, x() * scalingFactor,
             y() * scalingFactor, z() * scalingFactor);
     break;
   case 2:
-    fprintf(fp, "%10d%20.11e%20.11e\n", _index, x() * scalingFactor,
+    fprintf(fp, "%10ld%20.11e%20.11e\n", _index, x() * scalingFactor,
             y() * scalingFactor);
     break;
-  case 1: fprintf(fp, "%10d%20.11e\n", _index, x() * scalingFactor); break;
+  case 1: fprintf(fp, "%10ld%20.11e\n", _index, x() * scalingFactor); break;
   }
 }
 
@@ -399,20 +353,19 @@ void MVertex::writeBDF(FILE *fp, int format, double scalingFactor)
     double_to_char8(x1, xs);
     double_to_char8(y1, ys);
     double_to_char8(z1, zs);
-    fprintf(fp, "GRID,%d,%d,%s,%s,%s\n", _index, 0, xs, ys, zs);
+    fprintf(fp, "GRID,%ld,%d,%s,%s,%s\n", _index, 0, xs, ys, zs);
   }
   else if(format == 1) {
     // small field format (8 char par field, 10 per line)
     double_to_char8(x1, xs);
     double_to_char8(y1, ys);
     double_to_char8(z1, zs);
-    fprintf(fp, "GRID    %-8d%-8d%-8s%-8s%-8s\n", _index, 0, xs, ys, zs);
+    fprintf(fp, "GRID    %-8ld%-8d%-8s%-8s%-8s\n", _index, 0, xs, ys, zs);
   }
   else {
     // large field format (8 char first/last field, 16 char middle, 6 per line)
-    fprintf(fp, "GRID*   %-16d%-16d%-16.9G%-16.9G*N%-6d\n", _index, 0, x1, y1,
-            _index);
-    fprintf(fp, "*N%-6d%-16.9G\n", _index, z1);
+    fprintf(fp, "GRID*   %-16ld%-16d%-16.9G%-16.9G\n", _index, 0, x1, y1);
+    fprintf(fp, "*       %-16.9G\n", z1);
   }
 }
 
@@ -420,7 +373,7 @@ void MVertex::writeINP(FILE *fp, double scalingFactor)
 {
   if(_index < 0) return; // negative index vertices are never saved
 
-  fprintf(fp, "%d, %.14g, %.14g, %.14g\n", _index, x() * scalingFactor,
+  fprintf(fp, "%ld, %.14g, %.14g, %.14g\n", _index, x() * scalingFactor,
           y() * scalingFactor, z() * scalingFactor);
 }
 
@@ -428,7 +381,7 @@ void MVertex::writeKEY(FILE *fp, double scalingFactor)
 {
   if(_index < 0) return; // negative index vertices are never saved
 
-  fprintf(fp, "%d, %.14g, %.14g, %.14g\n", _index, x() * scalingFactor,
+  fprintf(fp, "%ld, %.14g, %.14g, %.14g\n", _index, x() * scalingFactor,
           y() * scalingFactor, z() * scalingFactor);
 }
 
@@ -436,7 +389,7 @@ void MVertex::writeDIFF(FILE *fp, bool binary, double scalingFactor)
 {
   if(_index < 0) return; // negative index vertices are never saved
 
-  fprintf(fp, " %d ( %25.16E , %25.16E , %25.16E )", _index,
+  fprintf(fp, " %ld ( %25.16E , %25.16E , %25.16E )", _index,
           x() * scalingFactor, y() * scalingFactor, z() * scalingFactor);
 }
 
@@ -445,10 +398,10 @@ void MVertex::writeSU2(FILE *fp, int dim, double scalingFactor)
   if(_index < 0) return; // negative index vertices are never saved
 
   if(dim == 2)
-    fprintf(fp, "%.16g %.16g %d\n", x() * scalingFactor, y() * scalingFactor,
+    fprintf(fp, "%.16g %.16g %ld\n", x() * scalingFactor, y() * scalingFactor,
             _index - 1);
   else
-    fprintf(fp, "%.16g %.16g %.16g %d\n", x() * scalingFactor,
+    fprintf(fp, "%.16g %.16g %.16g %ld\n", x() * scalingFactor,
             y() * scalingFactor, z() * scalingFactor, _index - 1);
 }
 
@@ -535,7 +488,7 @@ bool reparamMeshEdgeOnFace(MVertex *v1, MVertex *v2, GFace *gf, SPoint2 &param1,
     {
       double d = (p2[0].x() - p1[0].x()) * (p2[0].x() - p1[0].x()) +
                  (p2[0].y() - p1[0].y()) * (p2[0].y() - p1[0].y());
-      for(unsigned int i = 0; i < p2.size(); i++) {
+      for(std::size_t i = 0; i < p2.size(); i++) {
         double d1 = (p2[i].x() - p1[0].x()) * (p2[i].x() - p1[0].x()) +
                     (p2[i].y() - p1[0].y()) * (p2[i].y() - p1[0].y());
         if(d1 < d) {
@@ -547,7 +500,7 @@ bool reparamMeshEdgeOnFace(MVertex *v1, MVertex *v2, GFace *gf, SPoint2 &param1,
     {
       double d = (p2[0].x() - p1[0].x()) * (p2[0].x() - p1[0].x()) +
                  (p2[0].y() - p1[0].y()) * (p2[0].y() - p1[0].y());
-      for(unsigned int i = 0; i < p1.size(); i++) {
+      for(std::size_t i = 0; i < p1.size(); i++) {
         double d1 = (p2[0].x() - p1[i].x()) * (p2[0].x() - p1[i].x()) +
                     (p2[0].y() - p1[i].y()) * (p2[0].y() - p1[i].y());
         if(d1 < d) {
@@ -570,6 +523,12 @@ bool reparamMeshEdgeOnFace(MVertex *v1, MVertex *v2, GFace *gf, SPoint2 &param1,
 bool reparamMeshVertexOnFace(MVertex const *v, const GFace *gf, SPoint2 &param,
                              bool onSurface)
 {
+  if(!v->onWhat()){
+    Msg::Error("Mesh node %d is not classified: cannot reparametrize",
+               v->getNum());
+    return false;
+  }
+
   if(v->onWhat()->geomType() == GEntity::DiscreteCurve ||
      v->onWhat()->geomType() == GEntity::BoundaryLayerCurve) {
     param = gf->parFromPoint(SPoint3(v->x(), v->y(), v->z()), onSurface);
@@ -606,7 +565,8 @@ bool reparamMeshVertexOnFace(MVertex const *v, const GFace *gf, SPoint2 &param,
     v->getParameter(0, t);
     param = ge->reparamOnFace(gf, t, 1);
     if(!v->getParameter(0, t)) {
-      Msg::Error("Vertex %p not MEdgeVertex", v);
+      Msg::Warning("No parametric coordinate on node %d classified on curve %d",
+                   v->getNum(), ge->tag());
       return false;
       // param = gf->parFromPoint(SPoint3(v->x(), v->y(), v->z()), onSurface);
     }
