@@ -5,6 +5,11 @@
 //
 // Contributed by Anthony Royer.
 
+// FIXME: The partitioning code should be updated to
+// - make it deterministic!
+// - use int for partition tags (to match the type for other entities in Gmsh)
+// - use size_t for element/node tags, and thus the graph
+
 #include <vector>
 #include <set>
 #include <sstream>
@@ -137,28 +142,38 @@ public:
        CTX::instance()->mesh.partitionPriWeight == -1 ||
        CTX::instance()->mesh.partitionHexWeight == -1) {
       for(unsigned int i = 0; i < _ne; i++) {
-        if(!_element[i]) {
-          _vwgt[i] = 1;
-        }
-        else{
+        if(!_element[i]) { _vwgt[i] = 1; }
+        else {
           _vwgt[i] = (_element[i]->getDim() == (int)_dim ? 1 : 0);
         }
       }
     }
-    else{
+    else {
       for(unsigned int i = 0; i < _ne; i++) {
-        if(!_element[i]) {
-          _vwgt[i] = 1;
-        }
-        else{
+        if(!_element[i]) { _vwgt[i] = 1; }
+        else {
           switch(_element[i]->getType()) {
-          case TYPE_LIN: _vwgt[i] = CTX::instance()->mesh.partitionLinWeight; break;
-          case TYPE_TRI: _vwgt[i] = CTX::instance()->mesh.partitionTriWeight; break;
-          case TYPE_QUA: _vwgt[i] = CTX::instance()->mesh.partitionQuaWeight; break;
-          case TYPE_TET: _vwgt[i] = CTX::instance()->mesh.partitionTetWeight; break;
-          case TYPE_PYR: _vwgt[i] = CTX::instance()->mesh.partitionPyrWeight; break;
-          case TYPE_PRI: _vwgt[i] = CTX::instance()->mesh.partitionPriWeight; break;
-          case TYPE_HEX: _vwgt[i] = CTX::instance()->mesh.partitionHexWeight; break;
+          case TYPE_LIN:
+            _vwgt[i] = CTX::instance()->mesh.partitionLinWeight;
+            break;
+          case TYPE_TRI:
+            _vwgt[i] = CTX::instance()->mesh.partitionTriWeight;
+            break;
+          case TYPE_QUA:
+            _vwgt[i] = CTX::instance()->mesh.partitionQuaWeight;
+            break;
+          case TYPE_TET:
+            _vwgt[i] = CTX::instance()->mesh.partitionTetWeight;
+            break;
+          case TYPE_PYR:
+            _vwgt[i] = CTX::instance()->mesh.partitionPyrWeight;
+            break;
+          case TYPE_PRI:
+            _vwgt[i] = CTX::instance()->mesh.partitionPriWeight;
+            break;
+          case TYPE_HEX:
+            _vwgt[i] = CTX::instance()->mesh.partitionHexWeight;
+            break;
           default: _vwgt[i] = 1; break;
           }
         }
@@ -521,7 +536,7 @@ static int MakeGraph(GModel *const model, Graph &graph, int selectDim)
     model->getEntities(entities);
 
     std::set<MVertex *> vertices;
-    for(unsigned int i = 0; i < entities.size(); i++) {
+    for(std::size_t i = 0; i < entities.size(); i++) {
       if(entities[i]->dim() == selectDim) {
         switch(entities[i]->dim()) {
         case 3: tmp->add(static_cast<GRegion *>(entities[i])); break;
@@ -530,8 +545,8 @@ static int MakeGraph(GModel *const model, Graph &graph, int selectDim)
         case 0: tmp->add(static_cast<GVertex *>(entities[i])); break;
         default: break;
         }
-        for(unsigned int j = 0; j < entities[i]->getNumMeshElements(); j++) {
-          for(unsigned int k = 0;
+        for(std::size_t j = 0; j < entities[i]->getNumMeshElements(); j++) {
+          for(std::size_t k = 0;
               k < entities[i]->getMeshElement(j)->getNumVertices(); k++) {
             vertices.insert(entities[i]->getMeshElement(j)->getVertex(k));
           }
@@ -623,64 +638,118 @@ static int MakeGraph(GModel *const model, Graph &graph, int selectDim)
 
 // Partition a graph created by MakeGraph using Metis library. Returns: 0 =
 // success, 1 = error, 2 = exception thrown.
-static int PartitionGraph(Graph &graph)
+static int PartitionGraph(Graph &graph, bool verbose)
 {
 #ifdef HAVE_METIS
-  Msg::Info("Running METIS graph partitioner");
-
+  std::stringstream opt;
   try {
     int metisOptions[METIS_NOPTIONS];
     METIS_SetDefaultOptions((idx_t *)metisOptions);
 
+    opt << "ptype:";
     switch(CTX::instance()->mesh.metisAlgorithm) {
     case 1: // Recursive
       metisOptions[METIS_OPTION_PTYPE] = METIS_PTYPE_RB;
+      opt << "rb";
       break;
     case 2: // K-way
       metisOptions[METIS_OPTION_PTYPE] = METIS_PTYPE_KWAY;
+      opt << "kway";
+      break;
+    default:
+      opt << "default";
       break;
-    default: Msg::Info("Unknown partitioning algorithm"); break;
     }
 
+    opt << ", ufactor:";
+    if(CTX::instance()->mesh.metisMaxLoadImbalance >= 0) {
+      metisOptions[METIS_OPTION_UFACTOR] =
+        CTX::instance()->mesh.metisMaxLoadImbalance;
+      opt << CTX::instance()->mesh.metisMaxLoadImbalance;
+    }
+    else {
+      opt << "default";
+    }
+
+    opt << ", ctype:";
     switch(CTX::instance()->mesh.metisEdgeMatching) {
     case 1: // Random matching
       metisOptions[METIS_OPTION_CTYPE] = METIS_CTYPE_RM;
+      opt << "rm";
       break;
     case 2: // Sorted heavy-edge matching
       metisOptions[METIS_OPTION_CTYPE] = METIS_CTYPE_SHEM;
+      opt << "shem";
+      break;
+    default:
+      opt << "default";
       break;
-    default: Msg::Info("Unknown partitioning edge matching"); break;
     }
 
+    opt << ", rtype:";
     switch(CTX::instance()->mesh.metisRefinementAlgorithm) {
     case 1: // FM-based cut refinement
       metisOptions[METIS_OPTION_RTYPE] = METIS_RTYPE_FM;
+      opt << "fm";
       break;
     case 2: // Greedy boundary refinement
       metisOptions[METIS_OPTION_RTYPE] = METIS_RTYPE_GREEDY;
+      opt << "greedy";
       break;
     case 3: // Two-sided node FM refinement
       metisOptions[METIS_OPTION_RTYPE] = METIS_RTYPE_SEP2SIDED;
+      opt << "sep2sided";
       break;
     case 4: // One-sided node FM refinement
       metisOptions[METIS_OPTION_RTYPE] = METIS_RTYPE_SEP1SIDED;
+      opt << "sep1sided";
+      break;
+    default:
+      opt << "default";
       break;
-    default: Msg::Info("Unknown partitioning refinement algorithm"); break;
     }
 
+    opt << ", objtype:";
+    switch(CTX::instance()->mesh.metisObjective) {
+    case 1: // Min. cut
+      metisOptions[METIS_OPTION_OBJTYPE] = METIS_OBJTYPE_CUT;
+      opt << "cut";
+      break;
+    case 2: // Min. communication volume (slower)
+      metisOptions[METIS_OPTION_OBJTYPE] = METIS_OBJTYPE_VOL;
+      opt << "vol";
+      break;
+    default:
+      opt << "default";
+      break;
+    }
+
+    opt << ", minconn:";
+    switch(CTX::instance()->mesh.metisMinConn) {
+    case 0:
+      metisOptions[METIS_OPTION_MINCONN] = 0;
+      opt << 0;
+      break;
+    case 1:
+      metisOptions[METIS_OPTION_MINCONN] = 1;
+      opt << 1;
+      break;
+    default:
+      opt << "default";
+      break;
+    }
+
+    if(verbose)
+      Msg::Info("Running METIS with %s", opt.str().c_str());
+
     // C numbering
     metisOptions[METIS_OPTION_NUMBERING] = 0;
-    // Specifies the type of objective
-    metisOptions[METIS_OPTION_OBJTYPE] = METIS_OBJTYPE_CUT;
-    // Forces contiguous partitions.
-    // metisOptions[METIS_OPTION_CONTIG] = 1;
 
     int objval;
     unsigned int *epart = new unsigned int[graph.ne()];
     const unsigned int ne = graph.ne();
     const int numPart = graph.nparts();
     int ncon = 1;
-
     graph.fillDefaultWeights();
 
     int metisError = 0;
@@ -726,8 +795,8 @@ static int PartitionGraph(Graph &graph)
       }
     }
     graph.partition(epart);
-
-    Msg::Info("%d partitions, %d total edge-cuts", numPart, objval);
+    if(verbose)
+      Msg::Info("%d partitions, %d total edge-cuts", numPart, objval);
   } catch(...) {
     Msg::Error("METIS exception");
     return 2;
@@ -778,8 +847,8 @@ void removeVerticesEntity(ITERATOR it_beg, ITERATOR it_end)
 {
   for(ITERATOR it = it_beg; it != it_end; ++it) {
     for(std::size_t i = 0; i < (*it)->getNumMeshElements(); i++) {
-      for(GModel::size_type j = 0;
-          j < (*it)->getMeshElement(i)->getNumVertices(); j++) {
+      for(std::size_t j = 0; j < (*it)->getMeshElement(i)->getNumVertices();
+          j++) {
         (*it)->getMeshElement(i)->getVertex(j)->setEntity(0);
       }
     }
@@ -907,7 +976,7 @@ dividedNonConnectedEntities(GModel *const model, int dim,
 
         if(vertex->getNumMeshElements() > 1) {
           ret = true;
-          for(unsigned int i = 0; i < vertex->getNumMeshElements(); i++) {
+          for(std::size_t i = 0; i < vertex->getNumMeshElements(); i++) {
             // Create the new partitionVertex
             partitionVertex *pvertex = new partitionVertex(
               model, ++elementaryNumber, vertex->getPartitions());
@@ -1003,7 +1072,7 @@ dividedNonConnectedEntities(GModel *const model, int dim,
             }
           }
 
-          for(unsigned int i = 0; i < connectedElements.size(); i++) {
+          for(std::size_t i = 0; i < connectedElements.size(); i++) {
             // Create the new partitionEdge
             partitionEdge *pedge = new partitionEdge(
               model, ++elementaryNumber, 0, 0, edge->getPartitions());
@@ -1099,7 +1168,7 @@ dividedNonConnectedEntities(GModel *const model, int dim,
             }
           }
 
-          for(unsigned int i = 0; i < connectedElements.size(); i++) {
+          for(std::size_t i = 0; i < connectedElements.size(); i++) {
             // Create the new partitionFace
             partitionFace *pface = new partitionFace(model, ++elementaryNumber,
                                                      face->getPartitions());
@@ -1196,7 +1265,7 @@ dividedNonConnectedEntities(GModel *const model, int dim,
 
         if(connectedElements.size() > 1) {
           ret = true;
-          for(unsigned int i = 0; i < connectedElements.size(); i++) {
+          for(std::size_t i = 0; i < connectedElements.size(); i++) {
             // Create the new partitionRegion
             partitionRegion *pregion = new partitionRegion(
               model, ++elementaryNumber, region->getPartitions());
@@ -1420,7 +1489,7 @@ static MElement *getReferenceElement(
 
   // Take only the elements having the less partition in commun. For exemple we
   // take (1,2) and (3,8) but not (2,5,9) or (1,4,5,7)
-  for(unsigned int i = 0; i < elementPairs.size(); i++) {
+  for(std::size_t i = 0; i < elementPairs.size(); i++) {
     if(min > elementPairs[i].second.size()) {
       minSizeElementPairs.clear();
       min = elementPairs[i].second.size();
@@ -1434,7 +1503,7 @@ static MElement *getReferenceElement(
   // Check if the element separated different partitions
   if(minSizeElementPairs.size() == elementPairs.size()) {
     bool isEqual = true;
-    for(unsigned int i = 1; i < minSizeElementPairs.size(); i++) {
+    for(std::size_t i = 1; i < minSizeElementPairs.size(); i++) {
       if(minSizeElementPairs[i].second != minSizeElementPairs[0].second) {
         isEqual = false;
         break;
@@ -1445,7 +1514,7 @@ static MElement *getReferenceElement(
 
   while(minSizeElementPairs.size() > 1) {
     min = std::numeric_limits<unsigned int>::max();
-    for(unsigned int i = 0; i < minSizeElementPairs.size(); i++) {
+    for(std::size_t i = 0; i < minSizeElementPairs.size(); i++) {
       // The partition vector is sorted thus we can check only the first element
       if(minSizeElementPairs[i].second.size() == 0)
         return minSizeElementPairs[0].first;
@@ -1454,7 +1523,7 @@ static MElement *getReferenceElement(
       }
     }
 
-    for(unsigned int i = 0; i < minSizeElementPairs.size(); i++) {
+    for(std::size_t i = 0; i < minSizeElementPairs.size(); i++) {
       if(min == minSizeElementPairs[i].second[0]) {
         minSizeElementPairs[i].second.erase(
           minSizeElementPairs[i].second.begin());
@@ -1478,8 +1547,8 @@ static void getPartitionInVector(
   const std::vector<std::pair<MElement *, std::vector<unsigned int> > >
     &boundaryPair)
 {
-  for(unsigned int i = 0; i < boundaryPair.size(); i++) {
-    for(unsigned int j = 0; j < boundaryPair[i].second.size(); j++) {
+  for(std::size_t i = 0; i < boundaryPair.size(); i++) {
+    for(std::size_t j = 0; j < boundaryPair[i].second.size(); j++) {
       if(std::find(partitions.begin(), partitions.end(),
                    boundaryPair[i].second[j]) == partitions.end()) {
         partitions.push_back(boundaryPair[i].second[j]);
@@ -1515,9 +1584,7 @@ static PART_ENTITY *createPartitionEntity(
     for(typename std::multimap<PART_ENTITY *, GEntity *,
                                LESS_PART_ENTITY>::iterator it = ret.first;
         it != ret.second; ++it) {
-      if(referenceEntity == it->second) {
-        ppe = it->first;
-      }
+      if(referenceEntity == it->second) { ppe = it->first; }
     }
     if(!ppe) {
       // Create new entity and add them to the model
@@ -1571,7 +1638,7 @@ static partitionFace *assignPartitionBoundary(
     }
     else {
       MTriangleN *element =
-        new MTriangleN(verts, verts[0]->getPolynomialOrder());
+        new MTriangleN(verts, verts.back()->getPolynomialOrder());
       ppf->addTriangle(element);
     }
   }
@@ -1593,7 +1660,7 @@ static partitionFace *assignPartitionBoundary(
     }
     else {
       MQuadrangleN *element =
-        new MQuadrangleN(verts, verts[0]->getPolynomialOrder());
+        new MQuadrangleN(verts, verts.back()->getPolynomialOrder());
       ppf->addQuadrangle(element);
     }
   }
@@ -1841,8 +1908,8 @@ static void CreatePartitionTopology(
   std::set<GEdge *, GEntityLessThan> edges = model->getEdges();
   std::set<GVertex *, GEntityLessThan> vertices = model->getVertices();
 
-  if(meshDim >= 3) { // Create partition faces
-    Msg::Info(" - Creating partition faces");
+  if(meshDim >= 3) {
+    Msg::Info(" - Creating partition surfaces");
 
     for(unsigned int i = 0; i < model->getNumPartitions(); i++) {
       for(std::set<MElement *>::iterator it = boundaryElements[i].begin();
@@ -1871,7 +1938,7 @@ static void CreatePartitionTopology(
                                 elementToEntity, numFaceEntity);
       if(pf) {
         std::map<GEntity *, MElement *> boundaryEntityAndRefElement;
-        for(unsigned int i = 0; i < it->second.size(); i++)
+        for(std::size_t i = 0; i < it->second.size(); i++)
           boundaryEntityAndRefElement.insert(std::pair<GEntity *, MElement *>(
             elementToEntity[it->second[i].first], it->second[i].first));
 
@@ -1886,8 +1953,8 @@ static void CreatePartitionTopology(
     fillElementToEntity(model, elementToEntity, 2);
   }
 
-  if(meshDim >= 2) { // Create partition edges
-    Msg::Info(" - Creating partition edges");
+  if(meshDim >= 2) {
+    Msg::Info(" - Creating partition curves");
 
     if(meshDim == 2) {
       for(unsigned int i = 0; i < model->getNumPartitions(); i++) {
@@ -1964,7 +2031,7 @@ static void CreatePartitionTopology(
                                 elementToEntity, numEdgeEntity);
       if(pe) {
         std::map<GEntity *, MElement *> boundaryEntityAndRefElement;
-        for(unsigned int i = 0; i < it->second.size(); i++) {
+        for(std::size_t i = 0; i < it->second.size(); i++) {
           boundaryEntityAndRefElement.insert(std::pair<GEntity *, MElement *>(
             elementToEntity[it->second[i].first], it->second[i].first));
         }
@@ -1980,8 +2047,8 @@ static void CreatePartitionTopology(
     fillElementToEntity(model, elementToEntity, 1);
   }
 
-  if(meshDim >= 1) { // Create partition vertices
-    Msg::Info(" - Creating partition vertices");
+  if(meshDim >= 1) {
+    Msg::Info(" - Creating partition points");
     if(meshDim == 1) {
       for(unsigned int i = 0; i < model->getNumPartitions(); i++) {
         for(std::set<MElement *>::iterator it = boundaryElements[i].begin();
@@ -2051,7 +2118,7 @@ static void CreatePartitionTopology(
                                 elementToEntity, numVertexEntity);
       if(pv) {
         std::map<GEntity *, MElement *> boundaryEntityAndRefElement;
-        for(unsigned int i = 0; i < it->second.size(); i++)
+        for(std::size_t i = 0; i < it->second.size(); i++)
           boundaryEntityAndRefElement.insert(std::pair<GEntity *, MElement *>(
             elementToEntity[it->second[i].first], it->second[i].first));
 
@@ -2234,7 +2301,30 @@ static void AssignPhysicalName(GModel *model)
   }
 }
 
+int PartitionFace(GFace *gf, int np, int *p)
+{
+  GModel m;
+  m.add(gf);
+  for(size_t i = 0; i < gf->triangles.size(); ++i) {
+    for(size_t j = 0; j < 3; ++j) {
+      int n = gf->triangles[i]->getVertex(j)->getNum();
+      if(n > (int)m.getMaxVertexNumber()) m.setMaxVertexNumber(n);
+    }
+  }
+  Graph graph(&m);
+  if(MakeGraph(&m, graph, -1)) return 1;
+  graph.nparts(np);
+  if(PartitionGraph(graph, false)) return 1;
+  m.remove(gf);
+  //  for (size_t i=0;i<graph.ne();++i)p[i]=graph.partition(i);
+  for(unsigned int i = 0; i < graph.ne(); i++)
+    graph.element(i)->setPartition(graph.partition(i));
+
+  return 0;
+}
+
 // Partition a mesh into n parts. Returns: 0 = success, 1 = error
+
 int PartitionMesh(GModel *const model)
 {
   if(CTX::instance()->mesh.numPartitions <= 0) return 0;
@@ -2245,10 +2335,10 @@ int PartitionMesh(GModel *const model)
   Graph graph(model);
   if(MakeGraph(model, graph, -1)) return 1;
   graph.nparts(CTX::instance()->mesh.numPartitions);
-  if(PartitionGraph(graph)) return 1;
+  if(PartitionGraph(graph, true)) return 1;
 
   std::vector<int> elmCount[TYPE_MAX_NUM + 1];
-  for (int i = 0; i < TYPE_MAX_NUM + 1; i++) {
+  for(int i = 0; i < TYPE_MAX_NUM + 1; i++) {
     elmCount[i].resize(CTX::instance()->mesh.numPartitions, 0);
   }
 
@@ -2284,14 +2374,14 @@ int PartitionMesh(GModel *const model)
     int minCount = std::numeric_limits<int>::max();
     int maxCount = 0;
     int totCount = 0;
-    for (std::size_t j = 0; j < count.size(); j++) {
+    for(std::size_t j = 0; j < count.size(); j++) {
       minCount = std::min(count[j], minCount);
       maxCount = std::max(count[j], maxCount);
       totCount += count[j];
     }
     if(totCount > 0) {
-      Msg::Info(" - Repartition of %d %s(s): %d(min) %d(max) %g(avg)",
-                totCount, ElementType::nameOfParentType(i).c_str(),
+      Msg::Info(" - Repartition of %d %s: %d(min) %d(max) %g(avg)",
+                totCount, ElementType::nameOfParentType(i, totCount > 1).c_str(),
                 minCount, maxCount,
                 totCount / (double)CTX::instance()->mesh.numPartitions);
     }
@@ -2365,7 +2455,7 @@ int UnpartitionMesh(GModel *const model)
                        pvertex->points.end());
       }
       else {
-        for(unsigned int j = 0; j < pvertex->points.size(); j++)
+        for(std::size_t j = 0; j < pvertex->points.size(); j++)
           delete pvertex->points[j];
       }
       pvertex->points.clear();
@@ -2385,7 +2475,7 @@ int UnpartitionMesh(GModel *const model)
         assignToParent(verts, pedge, pedge->lines.begin(), pedge->lines.end());
       }
       else {
-        for(unsigned int j = 0; j < pedge->lines.size(); j++)
+        for(std::size_t j = 0; j < pedge->lines.size(); j++)
           delete pedge->lines[j];
       }
       pedge->lines.clear();
@@ -2415,9 +2505,9 @@ int UnpartitionMesh(GModel *const model)
                        pface->quadrangles.end());
       }
       else {
-        for(unsigned int j = 0; j < pface->triangles.size(); j++)
+        for(std::size_t j = 0; j < pface->triangles.size(); j++)
           delete pface->triangles[j];
-        for(unsigned int j = 0; j < pface->quadrangles.size(); j++)
+        for(std::size_t j = 0; j < pface->quadrangles.size(); j++)
           delete pface->quadrangles[j];
       }
       pface->triangles.clear();
@@ -2454,15 +2544,15 @@ int UnpartitionMesh(GModel *const model)
                        pregion->trihedra.end());
       }
       else {
-        for(unsigned int j = 0; j < pregion->tetrahedra.size(); j++)
+        for(std::size_t j = 0; j < pregion->tetrahedra.size(); j++)
           delete pregion->tetrahedra[j];
-        for(unsigned int j = 0; j < pregion->hexahedra.size(); j++)
+        for(std::size_t j = 0; j < pregion->hexahedra.size(); j++)
           delete pregion->hexahedra[j];
-        for(unsigned int j = 0; j < pregion->prisms.size(); j++)
+        for(std::size_t j = 0; j < pregion->prisms.size(); j++)
           delete pregion->prisms[j];
-        for(unsigned int j = 0; j < pregion->pyramids.size(); j++)
+        for(std::size_t j = 0; j < pregion->pyramids.size(); j++)
           delete pregion->pyramids[j];
-        for(unsigned int j = 0; j < pregion->trihedra.size(); j++)
+        for(std::size_t j = 0; j < pregion->trihedra.size(); j++)
           delete pregion->trihedra[j];
       }
       pregion->tetrahedra.clear();
@@ -2515,9 +2605,7 @@ int PartitionUsingThisSplit(GModel *const model, unsigned int npart,
 
   unsigned int *part = new unsigned int[graph.ne()];
   for(unsigned int i = 0; i < graph.ne(); i++) {
-    if(graph.element(i)) {
-      part[i] = elmToPartition[graph.element(i)] - 1;
-    }
+    if(graph.element(i)) { part[i] = elmToPartition[graph.element(i)] - 1; }
   }
 
   // Check and correct the topology
@@ -2575,8 +2663,8 @@ int ConvertOldPartitioningToNewOne(GModel *const model)
   std::set<unsigned int> partitions;
   std::vector<GEntity *> entities;
   model->getEntities(entities);
-  for(unsigned int i = 0; i < entities.size(); i++) {
-    for(unsigned int j = 0; j < entities[i]->getNumMeshElements(); j++) {
+  for(std::size_t i = 0; i < entities.size(); i++) {
+    for(std::size_t j = 0; j < entities[i]->getNumMeshElements(); j++) {
       MElement *e = entities[i]->getMeshElement(i);
       elmToPartition.insert(
         std::pair<MElement *, unsigned int>(e, e->getPartition()));
@@ -2602,6 +2690,13 @@ int ConvertOldPartitioningToNewOne(GModel *const model) { return 0; }
 int PartitionUsingThisSplit(GModel *const model, unsigned int npart,
                             hashmap<MElement *, unsigned int> &elmToPartition)
 {
+  Msg::Error("Gmsh must be compiled with METIS support to partition meshes");
+  return 0;
+}
+
+int PartitionFace(GFace *gf, int np, int *p)
+{
+  Msg::Error("Gmsh must be compiled with METIS support to partition meshes");
   return 0;
 }
 
