@@ -3,13 +3,15 @@
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _MESH_PARTITION_H_
-#define _MESH_PARTITION_H_
+#ifndef MESH_PARTITION_H
+#define MESH_PARTITION_H
 
 class GModel;
 class MElement;
+class GFace;
 
 int PartitionMesh(GModel *const model);
+int PartitionFace(GFace *gf, int np, int *p);
 int UnpartitionMesh(GModel *const model);
 int ConvertOldPartitioningToNewOne(GModel *const model);
 
