@@ -3,8 +3,8 @@
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _MESH_RELOCATE_VERTEX_H_
-#define _MESH_RELOCATE_VERTEX_H_
+#ifndef MESH_RELOCATE_VERTEX_H
+#define MESH_RELOCATE_VERTEX_H
 
 #include <vector>
 
@@ -16,5 +16,7 @@ void RelocateVertices(GRegion *region, int niter, double tol = 1.e-2);
 void RelocateVertices(std::vector<GRegion *> &regions, int niter,
                       double tol = 1.e-2);
 void RelocateVertices(GFace *, int niter, double tol = 1.e-6);
+void RelocateVerticesOfPyramids(GRegion *region, int niter, double tol= 1.e-2);
+void RelocateVerticesOfPyramids(std::vector<GRegion *> &regions, int niter, double tol= 1.e-2);
 
 #endif
