@@ -105,10 +105,10 @@ int sys2x2(double mat[2][2], double b[2], double res[2])
   double const det = mat[0][0] * mat[1][1] - mat[1][0] * mat[0][1];
 
   // TOLERANCE ! WARNING WARNING
-  if(norm == 0.0 || std::abs(det) / norm < 1.e-12) {
-    if(norm)
-      Msg::Debug("Assuming 2x2 matrix is singular (det/norm == %.16g)",
-                 std::abs(det) / norm);
+  if(norm == 0.0 || std::abs(det) / norm < 1.e-16) {
+    //    if(norm)
+    //      Msg::Debug("Assuming 2x2 matrix is singular (det/norm == %.16g)",
+    //		 std::abs(det) / norm);
     res[0] = res[1] = 0.0;
     return 0;
   }
@@ -437,9 +437,7 @@ double computeInnerRadiusForQuad(double *x, double *y, int i)
   // that is the point where the 2 bisectors meet
   double x_s = (c12 * b23 - c23 * b12) / (a23 * b12 - a12 * b23);
   double y_s = 0.;
-  if(b12 != 0) {
-    y_s = -a12 / b12 * x_s - c12 / b12;
-  }
+  if(b12 != 0) { y_s = -a12 / b12 * x_s - c12 / b12; }
   else {
     y_s = -a23 / b23 * x_s - c23 / b23;
   }
@@ -510,11 +508,11 @@ double ComputeScalarRep(int numComp, double *val, int tensorRep)
     return val[0];
   else if(numComp == 3)
     return sqrt(val[0] * val[0] + val[1] * val[1] + val[2] * val[2]);
-  else if(numComp == 9){
-    if(tensorRep == 0){ // Von-Mises
+  else if(numComp == 9) {
+    if(tensorRep == 0) { // Von-Mises
       return ComputeVonMises(val);
     }
-    else{
+    else {
       fullMatrix<double> tensor(3, 3);
       fullVector<double> S(3), imS(3);
       fullMatrix<double> V(3, 3);
@@ -525,10 +523,10 @@ double ComputeScalarRep(int numComp, double *val, int tensorRep)
         tensor(j, 2) = val[2 + j * 3];
       }
       tensor.eig(S, imS, V, rightV, true);
-      if(tensorRep == 1){ // max eigenvalue
+      if(tensorRep == 1) { // max eigenvalue
         return S(2);
       }
-      else{ // min eigenvalue
+      else { // min eigenvalue
         return S(0);
       }
     }
@@ -663,9 +661,7 @@ void invert_singular_matrix3x3(double MM[3][3], double II[3][3])
   fullMatrix<double> M(3, 3), V(3, 3);
   fullVector<double> W(3);
   for(i = 1; i <= n; i++) {
-    for(j = 1; j <= n; j++) {
-      M(i - 1, j - 1) = MM[i - 1][j - 1];
-    }
+    for(j = 1; j <= n; j++) { M(i - 1, j - 1) = MM[i - 1][j - 1]; }
   }
   M.svd(V, W);
   for(i = 1; i <= n; i++) {
@@ -697,9 +693,7 @@ bool newton_fd(bool (*func)(fullVector<double> &, fullVector<double> &, void *),
 
   for(int iter = 0; iter < MAXIT; iter++) {
     if(x.norm() > 1.e6) return false;
-    if(!func(x, f, data)) {
-      return false;
-    }
+    if(!func(x, f, data)) { return false; }
 
     bool isZero = false;
     for(int k = 0; k < N; k++) {
@@ -715,12 +709,8 @@ bool newton_fd(bool (*func)(fullVector<double> &, fullVector<double> &, void *),
       double h = EPS * fabs(x(j));
       if(h == 0.) h = EPS;
       x(j) += h;
-      if(!func(x, feps, data)) {
-        return false;
-      }
-      for(int i = 0; i < N; i++) {
-        J(i, j) = (feps(i) - f(i)) / h;
-      }
+      if(!func(x, feps, data)) { return false; }
+      for(int i = 0; i < N; i++) { J(i, j) = (feps(i) - f(i)) / h; }
       x(j) -= h;
     }
 
@@ -732,9 +722,7 @@ bool newton_fd(bool (*func)(fullVector<double> &, fullVector<double> &, void *),
 
     for(int i = 0; i < N; i++) x(i) -= relax * dx(i);
 
-    if(dx.norm() < tolx) {
-      return true;
-    }
+    if(dx.norm() < tolx) { return true; }
   }
   return false;
 }
@@ -842,7 +830,7 @@ void signedDistancesPointsTriangle(std::vector<double> &distances,
   closePts.clear();
   closePts.resize(pts_size);
 
-  for(unsigned int i = 0; i < pts_size; ++i) distances[i] = 1.e22;
+  for(std::size_t i = 0; i < pts_size; ++i) distances[i] = 1.e22;
 
   SVector3 t1 = p2 - p1;
   SVector3 t2 = p3 - p1;
@@ -859,7 +847,7 @@ void signedDistancesPointsTriangle(std::vector<double> &distances,
   double det = inv3x3(mat, inv);
   if(det == 0.0) return;
 
-  for(unsigned int i = 0; i < pts.size(); i++) {
+  for(std::size_t i = 0; i < pts.size(); i++) {
     double d;
     SPoint3 closePt;
     const SPoint3 &p = pts[i];
@@ -940,7 +928,7 @@ void signedDistancesPointsLine(std::vector<double> &distances,
   distances.resize(pts.size());
   closePts.clear();
   closePts.resize(pts.size());
-  for(unsigned int i = 0; i < pts.size(); i++) {
+  for(std::size_t i = 0; i < pts.size(); i++) {
     double d;
     SPoint3 closePt;
     const SPoint3 &p = pts[i];
@@ -1022,9 +1010,7 @@ int computeDistanceRatio(const double &y, const double &yp, const double &x,
     }
     else {
       b = (xp * y - x * yp) / (yp - y);
-      if(yp == 0.0) {
-        a = -(b + x) / y;
-      }
+      if(yp == 0.0) { a = -(b + x) / y; }
       else {
         a = -(b + xp) / yp;
       }
@@ -1063,9 +1049,7 @@ int computeDistanceRatio(const double &y, const double &yp, const double &x,
   }
   double rho = be * be - 4 * ae * ce;
   double x1, x2, y1, y2, propdist;
-  if(rho < 0) {
-    return 1;
-  }
+  if(rho < 0) { return 1; }
   else {
     x1 = -(be + sqrt(rho)) / (2.0 * ae);
     x2 = (-be + sqrt(rho)) / (2.0 * ae);
@@ -1095,23 +1079,17 @@ int computeDistanceRatio(const double &y, const double &yp, const double &x,
     }
     if(x1 == x2) {
       propdist = (y1 - y) / (yp - y);
-      if(propdist < 0.0) {
-        propdist = (y2 - y) / (yp - y);
-      }
+      if(propdist < 0.0) { propdist = (y2 - y) / (yp - y); }
     }
     else {
       if(xp != x) {
         propdist = (x1 - x) / (xp - x);
-        if(propdist < 0.0) {
-          propdist = (x2 - x) / (xp - x);
-        }
+        if(propdist < 0.0) { propdist = (x2 - x) / (xp - x); }
       }
       else {
         if(yp != y) {
           propdist = (y1 - y) / (yp - y);
-          if(propdist < 0.0) {
-            propdist = (y2 - y) / (yp - y);
-          }
+          if(propdist < 0.0) { propdist = (y2 - y) / (yp - y); }
         }
         else {
           propdist = 0.01;
@@ -1140,7 +1118,7 @@ void signedDistancesPointsEllipsePoint(std::vector<double> &distances,
   closePts.clear();
   closePts.resize(pts.size());
   double d;
-  for(unsigned int i = 0; i < pts.size(); i++) {
+  for(std::size_t i = 0; i < pts.size(); i++) {
     SPoint3 closePt;
     const SPoint3 &p = pts[i];
     signedDistancePointLine(p1, p2, p, d, closePt);
@@ -1173,7 +1151,7 @@ void signedDistancesPointsEllipseLine(
   closePts.clear();
   closePts.resize(pts.size());
   double d;
-  for(unsigned int i = 0; i < pts.size(); i++) {
+  for(std::size_t i = 0; i < pts.size(); i++) {
     SPoint3 closePt;
     const SPoint3 &p = pts[i];
     signedDistancePointLine(p1, p2, p, d, closePt);
@@ -1317,9 +1295,7 @@ void signedDistancesPointsEllipseLine(
       changeReferential(direction, p, closePt, p1, p2, &xp, &yp, &otherp, &x,
                         &y, &other);
       int result = 1;
-      if(fabs(other - otherp) > 0.01) {
-        result = 1;
-      }
+      if(fabs(other - otherp) > 0.01) { result = 1; }
       else {
         if(direction == 1) {
           result = computeDistanceRatio(y, yp, x, xp, &propdist, maxA, minA);
@@ -1539,7 +1515,7 @@ void projectPointsToPlane(const std::vector<SPoint3> &pts,
                           const mean_plane &meanPlane)
 {
   ptsProj.resize(pts.size());
-  for(unsigned int i = 0; i < pts.size(); i++) {
+  for(std::size_t i = 0; i < pts.size(); i++) {
     projectPointToPlane(pts[i], ptsProj[i], meanPlane);
   }
 }
@@ -1554,7 +1530,7 @@ void transformPointsIntoOrthoBasis(const std::vector<SPoint3> &ptsProj,
   SVector3 tangent, binormal;
   buildOrthoBasis(normal, tangent, binormal);
 
-  for(unsigned int i = 0; i < ptsProj.size(); i++) {
+  for(std::size_t i = 0; i < ptsProj.size(); i++) {
     SVector3 pp(ptsProj[i][0] - ptCG[0], ptsProj[i][1] - ptCG[1],
                 ptsProj[i][2] - ptCG[2]);
     pointsUV[i][0] = dot(pp, tangent);
@@ -1590,24 +1566,30 @@ bool catenary(double x0, double x1, double y0, double y1, double ys, int N,
   // ys - 1/b + 1/b cosh(b(x1-c)) - y1 = 0
   double param[5] = {x0, x1, y0, y1, ys};
   fullVector<double> x(2);
-  bool success = false;
+  bool success = false, physical = true;
+  double tolx = 1e-6 * fabs(x1 - x0);
+  double toly = 1e-6 * fabs(std::max(y0, y1) - ys);
   if(x0 != x1) {
     x(0) = 1. / (x1 - x0);
     x(1) = (x0 + x1) / 2.;
-    success = newton_fd(catenary_fct, x, param, 1., 1e-6 * fabs(x1 - x0));
+    success = newton_fd(catenary_fct, x, param, 1, tolx);
   }
   if(success) {
     double a = ys - 1 / x(0);
     for(int i = 0; i < N; i++) {
       double r = x0 + (i + 1) * (x1 - x0) / (N + 1);
       yp[i] = a + 1 / x(0) * cosh(x(0) * (r - x(1)));
+      if(yp[i] > std::max(y0, y1) + toly || yp[i] < ys - toly){
+        physical = false;
+        break;
+      }
     }
-    return true;
   }
-  else {
-    for(int i = 0; i < N; i++) {
-      yp[i] = y0 + (i + 1) * (y1 - y0) / (N + 1);
-    }
-    return false;
+  if(physical) return true;
+
+  // could not solve: return linear interpolation
+  for(int i = 0; i < N; i++) {
+    yp[i] = y0 + (i + 1) * (y1 - y0) / (N + 1);
   }
+  return false;
 }
