@@ -26,7 +26,6 @@
 #if defined(HAVE_SOLVER)
 #include "dofManager.h"
 #include "laplaceTerm.h"
-#include "linearSystemGMM.h"
 #include "linearSystemCSR.h"
 #include "linearSystemFull.h"
 #include "linearSystemPETSc.h"
@@ -206,15 +205,13 @@ void backgroundMesh2D::propagateValues(DoubleStorageType &dirichlet,
                                        bool in_parametric_plane)
 {
 #if defined(HAVE_SOLVER)
-  linearSystem<double> *_lsys = 0;
 #if defined(HAVE_PETSC)
-  _lsys = new linearSystemPETSc<double>;
+  linearSystemPETSc<double> *_lsys = new linearSystemPETSc<double>;
 #elif defined(HAVE_GMM)
-  linearSystemGmm<double> *_lsysb = new linearSystemGmm<double>;
-  _lsysb->setGmres(1);
-  _lsys = _lsysb;
+  linearSystemCSRGmm<double> *_lsys = new linearSystemCSRGmm<double>;
+  _lsys->setGmres(1);
 #else
-  _lsys = new linearSystemFull<double>;
+   linearSystemFull<double> *_lsys = new linearSystemFull<double>;
 #endif
 
   dofManager<double> myAssembler(_lsys);
