@@ -7,12 +7,12 @@ gmsh.option.setNumber("General.Terminal", 1)
 # Copied from discrete.py...
 gmsh.model.add("test");
 gmsh.model.addDiscreteEntity(2, 1)
-gmsh.model.mesh.setNodes(2, 1, [1, 2, 3, 4],
+gmsh.model.mesh.addNodes(2, 1, [1, 2, 3, 4],
                          [0., 0., 0.,
                           1., 0., 0.,
                           1., 1., 0.,
                           0., 1., 0.])
-gmsh.model.mesh.setElements(2, 1, [2], [[1, 2]],
+gmsh.model.mesh.addElements(2, 1, [2], [[1, 2]],
                             [[1, 2, 3,
                               1, 3, 4]])
 # ... end of copy
